@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,10 +36,10 @@ class StyledTextboxView: public TextboxView {
 
 	public:
 		StyledTextboxView(Textbox *txtbox, bool override_style=false);
-		~StyledTextboxView(void);
+		virtual ~StyledTextboxView();
 
 	protected slots:
-		void configureObject(void);
+		void configureObject();
 };
 
 #endif
