@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,16 +16,20 @@
 # Also, you can get the complete GNU General Public License at <http://www.gnu.org/licenses/>
 */
 #include "catalog.h"
+#include "pgmodelerns.h"
+#include "qtcompat/splitbehaviorcompat.h"
 
-const QString Catalog::QueryList=QString("list");
-const QString Catalog::QueryAttribs=QString("attribs");
-const QString Catalog::CatalogSchemasDir=QString("catalog");
-const QString Catalog::PgSqlTrue=QString("t");
-const QString Catalog::PgSqlFalse=QString("f");
-const QString Catalog::BoolField=QString("_bool");
-const QString Catalog::ArrayPattern=QString("((\\[)[0-9]+(\\:)[0-9]+(\\])=)?(\\{)((.)+(,)*)*(\\})$");
-const QString Catalog::GetExtensionObjsSql=QString("SELECT objid AS oid FROM pg_depend WHERE objid > 0 AND refobjid > 0 AND deptype='e'");
-const QString Catalog::PgModelerTempDbObj=QString("__pgmodeler_tmp");
+const QString Catalog::QueryList("list");
+const QString Catalog::QueryAttribs("attribs");
+const QString Catalog::PgSqlTrue("t");
+const QString Catalog::PgSqlFalse("f");
+const QString Catalog::BoolField("_bool");
+const QString Catalog::ArrayPattern("((\\[)[0-9]+(\\:)[0-9]+(\\])=)?(\\{)((.)+(,)*)*(\\})$");
+const QString Catalog::GetExtensionObjsSql("SELECT objid AS oid FROM pg_depend WHERE objid > 0 AND refobjid > 0 AND deptype='e'");
+const QString Catalog::PgModelerTempDbObj("__pgmodeler_tmp");
+const QString Catalog::InvFilterPattern("__invalid__pattern__");
+const QString Catalog::AliasPlaceholder("$alias$");
+const QString Catalog::EscapedNullChar("\\000");
 
 attribs_map Catalog::catalog_queries;
 
@@ -39,7 +43,8 @@ map<ObjectType, QString> Catalog::oid_fields=
 	{ObjectType::Table, "tb.oid"}, {ObjectType::Column, "cl.oid"}, {ObjectType::Constraint, "cs.oid"},
 	{ObjectType::Rule, "rl.oid"}, {ObjectType::Trigger, "tg.oid"}, {ObjectType::Index, "id.indexrelid"},
 	{ObjectType::EventTrigger, "et.oid"}, {ObjectType::Policy, "pl.oid"}, {ObjectType::ForeignDataWrapper, "fw.oid"},
-	{ObjectType::ForeignServer, "sv.oid"}, {ObjectType::UserMapping, "um.umid"}, {ObjectType::ForeignTable, "ft.oid"}
+	{ObjectType::ForeignServer, "sv.oid"}, {ObjectType::UserMapping, "um.umid"}, {ObjectType::ForeignTable, "ft.oid"},
+	{ObjectType::Transform, "tr.oid"}, {ObjectType::Procedure, "pr.oid"}
 };
 
 map<ObjectType, QString> Catalog::ext_oid_fields={
@@ -50,6 +55,14 @@ map<ObjectType, QString> Catalog::ext_oid_fields={
 	{ObjectType::Policy, "pl.polrelid"}
 };
 
+map<ObjectType, QString> Catalog::parent_aliases={
+	{ObjectType::Constraint, "tb"},
+	{ObjectType::Index, "tb"},
+	{ObjectType::Trigger, "tb"},
+	{ObjectType::Rule, "cl"},
+	{ObjectType::Policy, "tb"}
+};
+
 map<ObjectType, QString> Catalog::name_fields=
 { {ObjectType::Database, "datname"}, {ObjectType::Role, "rolname"}, {ObjectType::Schema,"nspname"},
 	{ObjectType::Language, "lanname"}, {ObjectType::Tablespace, "spcname"}, {ObjectType::Extension, "extname"},
@@ -58,15 +71,17 @@ map<ObjectType, QString> Catalog::name_fields=
 	{ObjectType::Conversion, "conname"}, {ObjectType::Cast, ""}, {ObjectType::View, "relname"},
 	{ObjectType::Sequence, "relname"}, {ObjectType::Domain, "typname"}, {ObjectType::Type, "typname"},
 	{ObjectType::Table, "relname"}, {ObjectType::Column, "attname"}, {ObjectType::Constraint, "conname"},
-	{ObjectType::Rule, "rulename"}, {ObjectType::Trigger, "tgname"}, {ObjectType::Index, "relname"},
+	{ObjectType::Rule, "rulename"}, {ObjectType::Trigger, "tgname"}, {ObjectType::Index, "cl.relname"},
 	{ObjectType::EventTrigger, "evtname"}, {ObjectType::Policy, "polname"}, {ObjectType::ForeignDataWrapper, "fdwname"},
-	{ObjectType::ForeignServer, "srvname"}, {ObjectType::ForeignTable, "relname"}
+	{ObjectType::ForeignServer, "srvname"}, {ObjectType::ForeignTable, "relname"}, {ObjectType::Transform, ""},
+	{ObjectType::Procedure, "proname"}
 };
 
-Catalog::Catalog(void)
+Catalog::Catalog()
 {
+	match_signature = true;
 	last_sys_oid=0;
-	setFilter(ExclExtensionObjs | ExclSystemObjs);
+	setQueryFilter(ExclExtensionObjs | ExclSystemObjs);
 }
 
 Catalog::Catalog(const Catalog &catalog)
@@ -114,12 +129,12 @@ void Catalog::setConnection(Connection &conn)
 	}
 }
 
-void Catalog::closeConnection(void)
+void Catalog::closeConnection()
 {
 	connection.close();
 }
 
-void Catalog::setFilter(unsigned filter)
+void Catalog::setQueryFilter(unsigned filter)
 {
 	bool list_all=(ListAllObjects & filter) == ListAllObjects;
 
@@ -141,19 +156,197 @@ void Catalog::setFilter(unsigned filter)
 	}
 }
 
-unsigned Catalog::getLastSysObjectOID(void)
+void Catalog::setObjectFilters(QStringList filters, bool only_matching, bool match_signature, QStringList tab_obj_types)
 {
-	return(last_sys_oid);
+	this->match_signature = match_signature;
+	obj_filters.clear();
+	extra_filter_conds.clear();
+
+	if(filters.isEmpty())
+		return;
+
+	ObjectType obj_type;
+	QString pattern, mode, aux_filter, parent_alias_ref, tab_filter = "^(%1)(.)+", _tmpl_filter;
+	QStringList values,	modes = { PgModelerNs::FilterWildcard, PgModelerNs::FilterRegExp };
+	map<ObjectType, QStringList> tab_patterns;
+	map<ObjectType, QStringList> parsed_filters;
+	attribs_map fmt_filter;
+
+	bool has_tab_filter = filters.indexOf(QRegExp(tab_filter.arg(BaseObject::getSchemaName(ObjectType::Table)))) >= 0,
+			 has_view_filter = filters.indexOf(QRegExp(tab_filter.arg(BaseObject::getSchemaName(ObjectType::View)))) >= 0,
+			 has_ftab_filter = filters.indexOf(QRegExp(tab_filter.arg(BaseObject::getSchemaName(ObjectType::ForeignTable)))) >= 0;
+
+	/* If we have at least one table (view or foreign table) filter
+	 * and the forced object types list we configure filters to force the
+	 * listing of table children objects, tied to the filters that list
+	 * the parent tables */
+	if(!tab_obj_types.isEmpty() && (has_tab_filter || has_ftab_filter || has_view_filter))
+	{
+		/* If the match_signature is set we need to use this extra string to reference parent's schema
+		 * in order to format its signature in the children catalog queries */
+		QString parent_sch_ref("ns.nspname || '.' ||");
+
+		/* Configuring the placeholder for the parent table name used in the construction of the creteria that filter
+		 * table names in forced table children objects filters.
+		 * This one comes in form of a regexp matching on oid::regclass::text */
+		parent_alias_ref = QString("%1 %2 ~* '(#)'")
+											 .arg(match_signature ? parent_sch_ref : "")
+											 .arg(AliasPlaceholder + QString(".relname"))
+											 .replace("#", "%1");
+
+		// Validating the provided table children objects types
+		for(auto &type_name : tab_obj_types)
+		{
+			if(!TableObject::isTableObject(BaseObject::getObjectType(type_name)))
+			{
+				throw Exception(Exception::getErrorMessage(ErrorCode::InvChildObjectTypeFilter).arg(type_name),
+												ErrorCode::InvChildObjectTypeFilter,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			}
+		}
+
+		tab_obj_types.removeDuplicates();
+	}
+
+	// The only matching filter is generated if there're filters configured
+	if(!filters.isEmpty() && only_matching)
+	{
+		for(auto &type : getFilterableObjectTypes())
+		{
+			/* We do not create exclusion filter for table objects if they were specified
+			 * by the users forced objects to be filtered */
+			if(tab_obj_types.contains(BaseObject::getSchemaName(type)))
+				continue;
+
+			if(filters.indexOf(QRegExp(QString("(%1)(.)+").arg(BaseObject::getSchemaName(type)))) < 0)
+				parsed_filters[type].append(QString("(%1)").arg(InvFilterPattern));
+		}
+	}
+
+	for(auto &filter : filters)
+	{
+		values = filter.split(PgModelerNs::FilterSeparator);
+
+		// Raises an error if the filter has an invalid field count
+		if(values.size() != 3)
+		{
+			throw Exception(Exception::getErrorMessage(ErrorCode::InvalidObjectFilter).arg(filter).arg(modes.join('|')),
+											ErrorCode::InvalidObjectFilter,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		}
+
+		obj_type = BaseObject::getObjectType(values[0]);
+		pattern = values[1];
+		mode = values[2];
+
+		// Raises an error if the filter has an invalid object type, pattern or mode
+		if(obj_type == ObjectType::BaseObject || pattern.isEmpty() || !modes.contains(mode))
+		{
+			throw Exception(Exception::getErrorMessage(ErrorCode::InvalidObjectFilter).arg(filter).arg(modes.join('|')),
+											ErrorCode::InvalidObjectFilter,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		}
+
+		// Converting wildcard patterns into regexp syntax
+		if(mode == PgModelerNs::FilterWildcard)
+		{
+			pattern.replace('.', "\\.");
+
+			// If the pattern has wildcard chars we replace them by (.)*
+			if(pattern.contains(PgModelerNs::WildcardChar))
+			{
+				QStringList list = pattern.split(PgModelerNs::WildcardChar, QtCompat::KeepEmptyParts);
+				QString any_str = "(.)*";
+				pattern.clear();
+
+				for(auto &word : list)
+				{
+					if(!word.isEmpty())
+						word = QString("(%1)").arg(word);
+				}
+
+				pattern = list.join(any_str);
+			}
+			else
+			{
+				/* If the pattern is wildcard mode but has not wildcard char we
+				 * assume that the matching should be exact so we prepend ^ and append $
+				 * in order to force a regular expression with exact match */
+				pattern.prepend('^');
+				pattern.append('$');
+			}
+		}
+
+		parsed_filters[obj_type].append(QString("(%1)").arg(pattern));
+
+		// Storing the table/view/foreign table patters if there're forced children objects to filter
+		if(!tab_obj_types.isEmpty() && BaseTable::isBaseTable(obj_type))
+			tab_patterns[obj_type].append(parent_alias_ref.arg(pattern));
+	}
+
+	if(!tab_obj_types.isEmpty())
+	{
+		map<ObjectType, QString> fmt_tab_patterns;
+		QStringList fmt_conds;
+
+		for(auto &itr : tab_patterns)
+			fmt_tab_patterns[itr.first] = QString("(%1) AND %2.relkind ")
+																		.arg(tab_patterns[itr.first].join(" OR "))
+																		.arg(AliasPlaceholder);
+
+		for(auto &type_name : tab_obj_types)
+		{
+			obj_type = BaseObject::getObjectType(type_name);
+
+			/* Configuring the "relkind" criteria according to the
+			 * flags indicating the presence of table/view/foreign table filters.
+			 * This relkinds will be used to filter table children objects specifically for
+			 * "relation kind" in pg_class in order to avoid bringing children object of
+			 * table types not filtered */
+			if(has_tab_filter && BaseObject::isChildObjectType(ObjectType::Table, obj_type))
+				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::Table] + QString("IN ('r','p')")));
+
+			if(has_view_filter && BaseObject::isChildObjectType(ObjectType::View, obj_type))
+				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::View] + QString("IN ('v','m')")));
+
+			if(has_ftab_filter && BaseObject::isChildObjectType(ObjectType::ForeignTable, obj_type))
+				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::ForeignTable] + QString("= 'f'")));
+
+			if(!fmt_conds.isEmpty())
+			{
+				extra_filter_conds[obj_type] = fmt_conds.join(" OR ").replace(AliasPlaceholder, parent_aliases[obj_type]);
+				fmt_conds.clear();
+			}
+		}
+	}
+
+	// Joining all configured filters in a single regexp
+	for(auto &itr : parsed_filters)
+		obj_filters[itr.first] = itr.second.join('|');
+}
+
+void Catalog::clearObjectFilter(ObjectType type)
+{
+	obj_filters.erase(type);
+	extra_filter_conds.erase(type);
+}
+
+void Catalog::clearObjectFilters()
+{
+	obj_filters.clear();
+	extra_filter_conds.clear();
+}
+
+unsigned Catalog::getLastSysObjectOID()
+{
+	return last_sys_oid;
 }
 
 bool Catalog::isSystemObject(unsigned oid)
 {
-	return(oid <= last_sys_oid);
+	return (oid <= last_sys_oid);
 }
 
 bool Catalog::isExtensionObject(unsigned oid)
 {
-	return(ext_obj_oids.contains(QString::number(oid)));
+	return ext_obj_oids.contains(QString::number(oid));
 }
 
 void Catalog::loadCatalogQuery(const QString &qry_id)
@@ -161,9 +354,7 @@ void Catalog::loadCatalogQuery(const QString &qry_id)
 	if(catalog_queries.count(qry_id)==0)
 	{
 		QFile input;
-		input.setFileName(GlobalAttributes::SchemasRootDir + GlobalAttributes::DirSeparator +
-							CatalogSchemasDir + GlobalAttributes::DirSeparator +
-							qry_id + GlobalAttributes::SchemaExt);
+		input.setFileName(GlobalAttributes::getSchemaFilePath(GlobalAttributes::CatalogSchemasDir, qry_id));
 
 		if(!input.open(QFile::ReadOnly))
 			throw Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotAccessed).arg(input.fileName()),
@@ -192,7 +383,7 @@ QString Catalog::getCatalogQuery(const QString &qry_type, ObjectType obj_type, b
 	attribs[qry_type]=Attributes::True;
 
 	if(exclude_sys_objs || list_only_sys_objs)
-		attribs[Attributes::LastSysOid]=QString("%1").arg(last_sys_oid);
+		attribs[Attributes::LastSysOid]=QString::number(last_sys_oid);
 
 	if(list_only_sys_objs)
 		attribs[Attributes::OidFilterOp]=QString("<=");
@@ -202,6 +393,17 @@ QString Catalog::getCatalogQuery(const QString &qry_type, ObjectType obj_type, b
 	if(obj_type==ObjectType::Type && exclude_array_types)
 		attribs[Attributes::ExcBuiltinArrays]=Attributes::True;
 
+	// If there's a name filter configured for the object type
+	if(obj_filters.count(obj_type))
+	{
+		attribs[Attributes::UseSignature] = match_signature ? Attributes::True : "";
+		attribs[Attributes::NameFilter] = obj_filters[obj_type];
+	}
+
+	// If there's a name filter configured for the object type
+	if(extra_filter_conds.count(obj_type))
+		attribs[Attributes::ExtraCondition] = extra_filter_conds[obj_type];
+
 	//Checking if the custom filter expression is present
 	if(attribs.count(Attributes::CustomFilter))
 	{
@@ -245,7 +447,7 @@ QString Catalog::getCatalogQuery(const QString &qry_type, ObjectType obj_type, b
 		sql+=QString(" LIMIT 1");
 	}
 
-	return(sql);
+	return sql;
 }
 
 void Catalog::executeCatalogQuery(const QString &qry_type, ObjectType obj_type, ResultSet &result, bool single_result, attribs_map attribs)
@@ -272,7 +474,7 @@ unsigned Catalog::getObjectCount(ObjectType obj_type, const QString &sch_name, c
 
 		executeCatalogQuery(QueryList, obj_type, res, false, extra_attribs);
 		res.accessTuple(ResultSet::FirstTuple);
-		return(res.getTupleCount());
+		return res.getTupleCount();
 	}
 	catch(Exception &e)
 	{
@@ -280,9 +482,31 @@ unsigned Catalog::getObjectCount(ObjectType obj_type, const QString &sch_name, c
 	}
 }
 
-unsigned Catalog::getFilter(void)
+unsigned Catalog::getQueryFilter()
 {
-	return(filter);
+	return filter;
+}
+
+map<ObjectType, QString> Catalog::getObjectFilters()
+{
+	return obj_filters;
+}
+
+vector<ObjectType> Catalog::getFilteredObjectTypes()
+{
+	vector<ObjectType> types;
+	QRegExp regexp = QRegExp(QString("(.)*(%1)(.)*").arg(InvFilterPattern));
+
+	for(auto &flt : obj_filters)
+	{
+		if(flt.second.indexOf(QRegExp(regexp)) < 0)
+			types.push_back(flt.first);
+	}
+
+	for(auto &ext_flt : extra_filter_conds)
+		types.push_back(ext_flt.first);
+
+	return types;
 }
 
 void Catalog::getObjectsOIDs(map<ObjectType, vector<unsigned> > &obj_oids, map<unsigned, vector<unsigned> > &col_oids, attribs_map extra_attribs)
@@ -298,7 +522,13 @@ void Catalog::getObjectsOIDs(map<ObjectType, vector<unsigned> > &obj_oids, map<u
 
 		for(ObjectType type : types)
 		{
-			attribs=getObjectsNames(type, QString(), QString(), extra_attribs);
+			/* We retrieve the object's attributes only if there're no filters configured
+			 * for the current type or in case of having filters, the type is registered in one of the
+			 * two filter structures */
+			if((obj_filters.empty() && extra_filter_conds.empty()) ||
+				 (!obj_filters.empty() && obj_filters.count(type) != 0) ||
+				 (!extra_filter_conds.empty() && TableObject::isTableObject(type) && extra_filter_conds.count(type) != 0))
+				attribs = getObjectsNames(type, "", "", extra_attribs);
 
 			for(auto &attr : attribs)
 			{
@@ -311,7 +541,7 @@ void Catalog::getObjectsOIDs(map<ObjectType, vector<unsigned> > &obj_oids, map<u
 				{
 					//Get the full set of attributes of the table
 					tab_oid=attr.first.toUInt();
-					tab_attribs=getObjectsAttributes(type, QString(), QString(), { tab_oid });
+					tab_attribs=getObjectsAttributes(type, "", "", { tab_oid });
 
 					//Retrieve the oid and names of the table's columns
 					col_attribs=getObjectsNames(ObjectType::Column, sch_names[tab_attribs[0][Attributes::Schema]], attr.second);
@@ -320,6 +550,8 @@ void Catalog::getObjectsOIDs(map<ObjectType, vector<unsigned> > &obj_oids, map<u
 						col_oids[tab_oid].push_back(col_attr.first.toUInt());
 				}
 			}
+
+			attribs.clear();
 		}
 	}
 	catch(Exception &e)
@@ -348,7 +580,7 @@ attribs_map Catalog::getObjectsNames(ObjectType obj_type, const QString &sch_nam
 			while(res.accessTuple(ResultSet::NextTuple));
 		}
 
-		return(objects);
+		return objects;
 	}
 	catch(Exception &e)
 	{
@@ -369,8 +601,8 @@ vector<attribs_map> Catalog::getObjectsNames(vector<ObjectType> obj_types, const
 		extra_attribs[Attributes::Schema]=sch_name;
 		extra_attribs[Attributes::Table]=tab_name;
 
-		for(ObjectType obj_type : obj_types)
-		{
+		for(auto &obj_type : obj_types)
+		{	
 			//Build the catalog query for the specified object type
 			sql=getCatalogQuery(QueryList, obj_type, false, extra_attribs);
 
@@ -398,18 +630,23 @@ vector<attribs_map> Catalog::getObjectsNames(vector<ObjectType> obj_types, const
 
 		if(res.accessTuple(ResultSet::FirstTuple))
 		{
+			QString obj_type_attr = QString(Attributes::ObjectType).replace('-', '_'),
+					parent_type_attr = QString(Attributes::ParentType).replace('-', '_');
+
 			do
 			{
 				attribs[Attributes::Oid]=res.getColumnValue(Attributes::Oid);
 				attribs[Attributes::Name]=res.getColumnValue(Attributes::Name);
-				attribs[Attributes::ObjectType]=res.getColumnValue(QString("object_type"));
+				attribs[Attributes::ObjectType]=res.getColumnValue(obj_type_attr);
+				attribs[Attributes::Parent]=res.getColumnValue(Attributes::Parent);
+				attribs[Attributes::ParentType]=res.getColumnValue(parent_type_attr);
 				objects.push_back(attribs);
 				attribs.clear();
 			}
 			while(res.accessTuple(ResultSet::NextTuple));
 		}
 
-		return(objects);
+		return objects;
 	}
 	catch(Exception &e)
 	{
@@ -435,7 +672,7 @@ attribs_map Catalog::getAttributes(const QString &obj_name, ObjectType obj_type,
 		import process on the classes that uses the Catalog */
 		obj_attribs[Attributes::ObjectType]=QString("%1").arg(enum_cast(obj_type));
 
-		return(obj_attribs);
+		return obj_attribs;
 	}
 	catch(Exception &e)
 	{
@@ -468,7 +705,7 @@ vector<attribs_map> Catalog::getMultipleAttributes(ObjectType obj_type, attribs_
 			while(res.accessTuple(ResultSet::NextTuple));
 		}
 
-		return(obj_attribs);
+		return obj_attribs;
 	}
 	catch(Exception &e)
 	{
@@ -502,7 +739,7 @@ vector<attribs_map> Catalog::getMultipleAttributes(const QString &catalog_sch, a
 			while(res.accessTuple(ResultSet::NextTuple));
 		}
 
-		return(obj_attribs);
+		return obj_attribs;
 	}
 	catch(Exception &e)
 	{
@@ -517,10 +754,10 @@ QString Catalog::getCommentQuery(const QString &oid_field, bool is_shared_obj)
 	try
 	{
 		attribs_map attribs={{Attributes::Oid, oid_field},
-												 {Attributes::SharedObj, (is_shared_obj ? Attributes::True : QString())}};
+												 {Attributes::SharedObj, (is_shared_obj ? Attributes::True : "")}};
 
 		loadCatalogQuery(query_id);
-		return(schparser.getCodeDefinition(attribs).simplified());
+		return schparser.getCodeDefinition(attribs).simplified();
 	}
 	catch(Exception &e)
 	{
@@ -540,7 +777,7 @@ QString Catalog::getNotExtObjectQuery(const QString &oid_field)
 
 
 		loadCatalogQuery(query_id);
-		return(schparser.getCodeDefinition(attribs).simplified());
+		return schparser.getCodeDefinition(attribs).simplified();
 	}
 	catch(Exception &e)
 	{
@@ -572,7 +809,7 @@ attribs_map Catalog::changeAttributeNames(const attribs_map &attribs)
 		itr++;
 	}
 
-	return(new_attribs);
+	return new_attribs;
 }
 
 QString Catalog::createOidFilter(const vector<unsigned> &oids)
@@ -585,15 +822,16 @@ QString Catalog::createOidFilter(const vector<unsigned> &oids)
 	if(!filter.isEmpty())
 		filter.remove(filter.size()-1,1);
 
-	return(filter);
+	return filter;
 }
 
 vector<attribs_map> Catalog::getObjectsAttributes(ObjectType obj_type, const QString &schema, const QString &table, const vector<unsigned> &filter_oids, attribs_map extra_attribs)
 {
 	try
 	{
-		bool is_shared_obj=(obj_type==ObjectType::Database ||	obj_type==ObjectType::Role ||	obj_type==ObjectType::Tablespace ||
-												obj_type==ObjectType::Language || obj_type==ObjectType::Cast);
+		bool is_shared_obj=(obj_type==ObjectType::Database ||	obj_type==ObjectType::Role ||
+												obj_type==ObjectType::Tablespace || obj_type==ObjectType::Language ||
+												obj_type==ObjectType::Cast);
 
 		extra_attribs[Attributes::Schema]=schema;
 		extra_attribs[Attributes::Table]=table;
@@ -605,12 +843,12 @@ vector<attribs_map> Catalog::getObjectsAttributes(ObjectType obj_type, const QSt
 		if(obj_type != ObjectType::Column)
 			extra_attribs[Attributes::Comment]=getCommentQuery(oid_fields[obj_type], is_shared_obj);
 
-		return(getMultipleAttributes(obj_type, extra_attribs));
+		return getMultipleAttributes(obj_type, extra_attribs);
 	}
 	catch(Exception &e)
 	{
 		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e,
-						QApplication::translate("Catalog","Object type: %1","", -1).arg(BaseObject::getSchemaName(obj_type)));
+						QString("catalog: %1").arg(BaseObject::getSchemaName(obj_type)));
 	}
 }
 
@@ -619,7 +857,7 @@ attribs_map Catalog::getObjectAttributes(ObjectType obj_type, unsigned oid, cons
 	try
 	{
 		vector<attribs_map> attribs_vect=getObjectsAttributes(obj_type, sch_name, tab_name, { oid }, extra_attribs);
-		return(attribs_vect.empty() ? attribs_map() : attribs_vect[0]);
+		return (attribs_vect.empty() ? attribs_map() : attribs_vect[0]);
 	}
 	catch(Exception &e)
 	{
@@ -645,11 +883,11 @@ QString Catalog::getObjectOID(const QString &name, ObjectType obj_type, const QS
 											ErrorCode::Custom,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		else if(res.isEmpty())
-			return("0");
+			return "0";
 		else
 		{
 			res.accessTuple(ResultSet::FirstTuple);
-			return(res.getColumnValue(Attributes::Oid));
+			return res.getColumnValue(Attributes::Oid);
 		}
 	}
 	catch(Exception &e)
@@ -659,7 +897,7 @@ QString Catalog::getObjectOID(const QString &name, ObjectType obj_type, const QS
 	}
 }
 
-attribs_map Catalog::getServerAttributes(void)
+attribs_map Catalog::getServerAttributes()
 {
 	attribs_map attribs;
 
@@ -697,7 +935,41 @@ attribs_map Catalog::getServerAttributes(void)
 						QApplication::translate("Catalog","Object type: server","", -1));
 	}
 
-	return(attribs);
+	return attribs;
+}
+
+unsigned Catalog::getObjectCount(bool incl_sys_objs)
+{
+	unsigned count = 0;
+
+	try
+	{
+		ResultSet res = ResultSet();
+		QString sql, attr_name;
+		attribs_map tuple, attribs;
+
+		if(!incl_sys_objs)
+			attribs[Attributes::LastSysOid]=QString::number(last_sys_oid);
+
+		loadCatalogQuery(Attributes::ObjCount);
+		schparser.ignoreUnkownAttributes(true);
+		schparser.ignoreEmptyAttributes(true);
+		sql = schparser.getCodeDefinition(attribs).simplified();
+		connection.executeDMLCommand(sql, res);
+
+		if(res.accessTuple(ResultSet::FirstTuple))
+		{
+			tuple = res.getTupleValues();
+			count = tuple[Attributes::ObjCount].toUInt();
+		}
+	}
+	catch(Exception &e)
+	{
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e,
+						QApplication::translate("Catalog","Object type: server","", -1));
+	}
+
+	return count;
 }
 
 QStringList Catalog::parseArrayValues(const QString &array_val)
@@ -714,66 +986,105 @@ QStringList Catalog::parseArrayValues(const QString &array_val)
 		if(value.contains('"'))
 			list=parseDefaultValues(value, QString("\""), QString(","));
 		else
-			list=value.split(',', QString::SkipEmptyParts);
+			list=value.split(',', QtCompat::SkipEmptyParts);
 	}
 
-	return(list);
+	return list;
 }
 
-QStringList Catalog::parseDefaultValues(const QString &def_vals, const QString &str_delim, const QString &val_sep)
+QStringList Catalog::parseDefaultValues(const QString &def_values, const QString &str_delim, const QString &val_sep)
 {
-	int idx=0, delim_start, delim_end, sep_idx, pos=0;
+	int idx = 0, delim_start, delim_end, sep_idx, pos = -1;
 	QStringList values;
+	QString array_expr = "ARRAY[", aux_def_vals = def_values, array_val;
 
-	while(idx < def_vals.size())
+	/* Special case for ARRAY[M, .. , N] values:
+	 *
+	 * We need to replace temporarily the element separators (generally comma)
+	 * by another character in order to avoid splitting the string in a vector
+	 * greater than the passed default values define. *
+	 *
+	 * Example:
+	 * Supposing the default value string "0, '*', ARRAY[0, 1, 2 ,3], 'foo', ARRAY['a', 'b', 'c']"
+	 * If the elements ARRAY[] are not treated properly, in the final result we'll have
+	 * a QStringList with 10 elements but the correct must be 5 since the commas inside ARRAY[]
+	 * must not be considered when splitting the provided string. */
+
+	do
+	{
+		pos = aux_def_vals.indexOf(array_expr, pos + 1);
+
+		if(pos >= 0)
+		{
+			idx = aux_def_vals.indexOf(QString("], "), pos + 1);
+
+			if(idx < 0)
+				idx = aux_def_vals.indexOf(']', pos + 1);
+
+			array_val = aux_def_vals.mid(pos, (idx - pos) + 1);
+			array_val.replace(",", PgModelerNs::DataSeparator);
+			aux_def_vals.replace(pos, array_val.size(), array_val);
+		}
+	}
+	while(pos >= 0);
+
+	pos = idx = 0;
+	while(idx < aux_def_vals.size())
 	{
 		//Get the index of string delimiters (default: ')
-		delim_start=def_vals.indexOf(str_delim, idx);
-		delim_end=def_vals.indexOf(str_delim, delim_start + 1);
+		delim_start = aux_def_vals.indexOf(str_delim, idx);
+		delim_end = aux_def_vals.indexOf(str_delim, delim_start + 1);
 
 		/* Get the index of value separator on default value string
 			 (by default the pg_get_expr separates values by comma and space (, ) */
-		sep_idx=def_vals.indexOf(val_sep, idx);
+		sep_idx = aux_def_vals.indexOf(val_sep, idx);
 
 		/* If there is no separator on string (only one value) or the is
 			 beyond the string delimiters or even there is no string delimiter on string */
 		if(sep_idx < 0 ||
 				(sep_idx >=0 && delim_start >= 0 && delim_end >= 0 &&
-				 (sep_idx < delim_start || sep_idx > delim_end)) ||
-				(sep_idx >=0 && (delim_start < 0 || delim_end < 0)))
+				(sep_idx < delim_start || sep_idx > delim_end)) ||
+				(sep_idx >= 0 && (delim_start < 0 || delim_end < 0)))
 		{
 			//Extract the value from the current position
-			values.push_back(def_vals.mid(pos, sep_idx-pos).trimmed());
+			values.push_back(aux_def_vals.mid(pos, sep_idx - pos).trimmed());
 
 			//If there is no separator on string indicates that it contains only one value
 			if(sep_idx < 0)
 				//Forcing the loop abort
-				idx=def_vals.size();
+				idx = aux_def_vals.size();
 			else
 			{
 				//Passing to the next value right after the separator
-				pos=sep_idx+1;
-				idx=pos;
+				pos = sep_idx+1;
+				idx = pos;
 			}
 		}
 		/* If the separator is between a string delimitation e.g.'abc, def' it will be ignored
 		and the current postion will be moved to the first char after string delimiter */
-		else if(delim_start>=0 && delim_end >= 0 &&
-				sep_idx >= delim_start && sep_idx <=delim_end)
+		else if(delim_start >= 0 && delim_end >= 0 &&
+						sep_idx >= delim_start && sep_idx <= delim_end)
 		{
-			idx=delim_end+1;
+			idx = delim_end + 1;
 
 			/* If the index reaches the end of string but the cursor (pos) isn't at end
 			indicates that the last values wasn't retrieved, this way, the value will be
 			pushed to list of values */
-			if(idx >= def_vals.size() && pos < def_vals.size())
-				values.push_back(def_vals.mid(pos, def_vals.size()));
+			if(idx >= aux_def_vals.size() && pos < aux_def_vals.size())
+				values.push_back(aux_def_vals.mid(pos, aux_def_vals.size()));
 		}
 		else
 			idx++;
 	}
 
-	return(values);
+	// Converting back the separators of elements in ARRAY[] values
+	for(auto &val : values)
+	{
+		if(val.contains(array_expr))
+			val.replace(PgModelerNs::DataSeparator, ",");
+	}
+
+	return values;
 }
 
 QStringList Catalog::parseRuleCommands(const QString &cmds)
@@ -783,7 +1094,7 @@ QStringList Catalog::parseRuleCommands(const QString &cmds)
 
 	start=cmd_regexp.indexIn(cmds) + cmd_regexp.matchedLength();
 	end=cmds.lastIndexOf(';');
-	return(cmds.mid(start,(end - start) + 1).split(';', QString::SkipEmptyParts));
+	return (cmds.mid(start,(end - start) + 1).split(';', QtCompat::SkipEmptyParts));
 }
 
 QStringList Catalog::parseIndexExpressions(const QString &expr)
@@ -828,7 +1139,53 @@ QStringList Catalog::parseIndexExpressions(const QString &expr)
 		}
 	}
 
-	return(expressions);
+	return expressions;
+}
+
+vector<ObjectType> Catalog::getFilterableObjectTypes()
+{
+	static vector<ObjectType> types = BaseObject::getObjectTypes(true, { ObjectType::Relationship,
+																																			 ObjectType::BaseRelationship,
+																																			 ObjectType::Textbox,
+																																			 ObjectType::GenericSql,
+																																			 ObjectType::Permission,
+																																			 ObjectType::Database,
+																																			 ObjectType::Column,
+																																			 ObjectType::Tag });
+
+	return types;
+}
+
+QStringList Catalog::getFilterableObjectNames()
+{
+	static QStringList names;
+
+	if(names.isEmpty())
+	{
+		QStringList aux_names = {
+			BaseObject::getSchemaName(ObjectType::View),
+			BaseObject::getSchemaName(ObjectType::Table),
+			BaseObject::getSchemaName(ObjectType::Schema)
+		};
+
+		for(auto &type : getFilterableObjectTypes())
+		{
+			if(type == ObjectType::Table ||
+				 type == ObjectType::View ||
+				 type == ObjectType::Schema)
+				continue;
+
+			names.append(BaseObject::getSchemaName(type));
+		}
+
+		names.sort();
+
+		//Placing table types and schema at the start of the list
+		for(auto &name : aux_names)
+			names.prepend(name);
+	}
+
+	return names;
 }
 
 void Catalog::operator = (const Catalog &catalog)
@@ -843,6 +1200,8 @@ void Catalog::operator = (const Catalog &catalog)
 		this->exclude_sys_objs=catalog.exclude_sys_objs;
 		this->exclude_array_types=catalog.exclude_array_types;
 		this->list_only_sys_objs=catalog.list_only_sys_objs;
+		this->obj_filters=catalog.obj_filters;
+		this->extra_filter_conds=catalog.extra_filter_conds;
 		this->connection.connect();
 	}
 	catch(Exception &e)
