@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,22 +18,23 @@
 
 #include "basetable.h"
 
-BaseTable::BaseTable(void)
+BaseTable::BaseTable()
 {
 	tag=nullptr;
 	obj_type=ObjectType::BaseTable;
-	attributes[Attributes::Tag]=QString();
-	attributes[Attributes::MaxObjCount]=QString();
-	attributes[Attributes::CollapseMode]=QString();
-	attributes[Attributes::Pagination]=QString();
-	attributes[Attributes::AttribsPage]=QString();
-	attributes[Attributes::ExtAttribsPage]=QString();
+	attributes[Attributes::Tag]="";
+	attributes[Attributes::MaxObjCount]="";
+	attributes[Attributes::CollapseMode]="";
+	attributes[Attributes::Pagination]="";
+	attributes[Attributes::AttribsPage]="";
+	attributes[Attributes::ExtAttribsPage]="";
+	attributes[Attributes::ZValue]="";
 	pagination_enabled = false;
 	collapse_mode = CollapseMode::NotCollapsed;
 	resetCurrentPages();
 }
 
-void BaseTable::resetCurrentPages(void)
+void BaseTable::resetCurrentPages()
 {
 	curr_page[AttribsSection] = 0;
 	curr_page[ExtAttribsSection] = 0;
@@ -45,23 +46,23 @@ void BaseTable::setTag(Tag *tag)
 	this->tag=tag;
 }
 
-Tag *BaseTable::getTag(void)
+Tag *BaseTable::getTag()
 {
-	return(tag);
+	return tag;
 }
 
-bool BaseTable::isBaseTable(ObjectType obj_type)
+bool BaseTable::isBaseTable(ObjectType obj_tp)
 {
-	return(obj_type == ObjectType::Table ||
-				 obj_type == ObjectType::ForeignTable ||
-				 obj_type == ObjectType::View);
+	return (obj_tp == ObjectType::Table ||
+				 obj_tp == ObjectType::ForeignTable ||
+				 obj_tp == ObjectType::View);
 }
 
 QString BaseTable::getAlterDefinition(BaseObject *object)
 {
 	try
 	{
-		return(BaseObject::getAlterDefinition(object));
+		return BaseObject::getAlterDefinition(object);
 	}
 	catch(Exception &e)
 	{
@@ -75,9 +76,9 @@ void BaseTable::operator = (BaseTable &tab)
 	this->tag=tab.tag;
 }
 
-CollapseMode BaseTable::getCollapseMode(void)
+CollapseMode BaseTable::getCollapseMode()
 {
-	return(collapse_mode);
+	return collapse_mode;
 }
 
 void BaseTable::setPaginationEnabled(bool value)
@@ -89,9 +90,9 @@ void BaseTable::setPaginationEnabled(bool value)
 		resetCurrentPages();
 }
 
-bool BaseTable::isPaginationEnabled(void)
+bool BaseTable::isPaginationEnabled()
 {
-	return(pagination_enabled);
+	return pagination_enabled;
 }
 
 void BaseTable::setCurrentPage(unsigned section_id, unsigned value)
@@ -108,7 +109,7 @@ unsigned BaseTable::getCurrentPage(unsigned section_id)
 	if(section_id > ExtAttribsSection)
 		throw Exception(ErrorCode::RefElementInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
-	return(curr_page[section_id]);
+	return curr_page[section_id];
 }
 
 void BaseTable::setCollapseMode(CollapseMode coll_mode)
@@ -116,3 +117,9 @@ void BaseTable::setCollapseMode(CollapseMode coll_mode)
 	setCodeInvalidated(collapse_mode != coll_mode);
 	collapse_mode = coll_mode;
 }
+
+void BaseTable::setZValue(int z_value)
+{
+	setCodeInvalidated(this->z_value != z_value);
+	BaseGraphicObject::setZValue(z_value);
+}
