@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 #include "constraint.h"
 
-Constraint::Constraint(void)
+Constraint::Constraint()
 {
 	ref_table=nullptr;
 	obj_type=ObjectType::Constraint;
@@ -27,30 +27,30 @@ Constraint::Constraint(void)
 	fill_factor=0;
 	index_type=BaseType::Null;
 
-	attributes[Attributes::PkConstr]=QString();
-	attributes[Attributes::FkConstr]=QString();
-	attributes[Attributes::CkConstr]=QString();
-	attributes[Attributes::UqConstr]=QString();
-	attributes[Attributes::ExConstr]=QString();
-	attributes[Attributes::RefTable]=QString();
-	attributes[Attributes::SrcColumns]=QString();
-	attributes[Attributes::DstColumns]=QString();
-	attributes[Attributes::DelAction]=QString();
-	attributes[Attributes::UpdAction]=QString();
-	attributes[Attributes::Expression]=QString();
-	attributes[Attributes::Type]=QString();
-	attributes[Attributes::ComparisonType]=QString();
-	attributes[Attributes::DeferType]=QString();
-	attributes[Attributes::IndexType]=QString();
-	attributes[Attributes::Deferrable]=QString();
-	attributes[Attributes::Table]=QString();
-	attributes[Attributes::DeclInTable]=QString();
-	attributes[Attributes::Factor]=QString();
-	attributes[Attributes::NoInherit]=QString();
-	attributes[Attributes::Elements]=QString();
+	attributes[Attributes::PkConstr]="";
+	attributes[Attributes::FkConstr]="";
+	attributes[Attributes::CkConstr]="";
+	attributes[Attributes::UqConstr]="";
+	attributes[Attributes::ExConstr]="";
+	attributes[Attributes::RefTable]="";
+	attributes[Attributes::SrcColumns]="";
+	attributes[Attributes::DstColumns]="";
+	attributes[Attributes::DelAction]="";
+	attributes[Attributes::UpdAction]="";
+	attributes[Attributes::Expression]="";
+	attributes[Attributes::Type]="";
+	attributes[Attributes::ComparisonType]="";
+	attributes[Attributes::DeferType]="";
+	attributes[Attributes::IndexType]="";
+	attributes[Attributes::Deferrable]="";
+	attributes[Attributes::Table]="";
+	attributes[Attributes::DeclInTable]="";
+	attributes[Attributes::Factor]="";
+	attributes[Attributes::NoInherit]="";
+	attributes[Attributes::Elements]="";
 }
 
-Constraint::~Constraint(void)
+Constraint::~Constraint()
 {
 	columns.clear();
 	ref_columns.clear();
@@ -109,7 +109,20 @@ bool Constraint::isColumnExists(Column *column, unsigned col_type)
 		itr++;
 	}
 
-	return(found);
+	return found;
+}
+
+bool Constraint::isColumnsExist(vector<Column *> columns, unsigned col_type)
+{
+	bool is_ref = false;
+
+	for(auto &col : columns)
+	{
+		is_ref = isColumnExists(col, col_type);
+		if(!is_ref) break;
+	}
+
+	return is_ref;
 }
 
 bool Constraint::isColumnReferenced(Column *column, bool search_only_ref_cols)
@@ -140,7 +153,7 @@ bool Constraint::isColumnReferenced(Column *column, bool search_only_ref_cols)
 		}
 	}
 
-	return(found);
+	return found;
 }
 
 void Constraint::addColumn(Column *column, unsigned col_type)
@@ -261,32 +274,32 @@ void Constraint::setNoInherit(bool value)
 	no_inherit=value;
 }
 
-unsigned Constraint::getFillFactor(void)
+unsigned Constraint::getFillFactor()
 {
-	return(fill_factor);
+	return fill_factor;
 }
 
-ConstraintType Constraint::getConstraintType(void)
+ConstraintType Constraint::getConstraintType()
 {
-	return(constr_type);
+	return constr_type;
 }
 
 ActionType Constraint::getActionType(unsigned act_id)
 {
 	if(act_id==DeleteAction)
-		return(del_action);
+		return del_action;
 	else
-	  return(upd_action);
+		return upd_action;
 }
 
 vector<Column *> Constraint::getColumns(unsigned col_type)
 {
-  return(col_type==SourceCols ? columns : ref_columns);
+  return (col_type==SourceCols ? columns : ref_columns);
 }
 
-QString Constraint::getExpression(void)
+QString Constraint::getExpression()
 {
-	return(expression);
+	return expression;
 }
 
 Column *Constraint::getColumn(unsigned col_idx, unsigned col_type)
@@ -299,7 +312,7 @@ Column *Constraint::getColumn(unsigned col_idx, unsigned col_type)
 	if(col_idx>=col_list->size())
 		throw Exception(ErrorCode::RefColumnInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
-	return(col_list->at(col_idx));
+	return col_list->at(col_idx);
 }
 
 Column *Constraint::getColumn(const QString &name, unsigned col_type)
@@ -320,24 +333,24 @@ Column *Constraint::getColumn(const QString &name, unsigned col_type)
 		else break;
 	}
 
-	if(found) return(*itr_col);
-	else return(nullptr);
+	if(found) return *itr_col;
+	else return nullptr;
 }
 
-BaseTable *Constraint::getReferencedTable(void)
+BaseTable *Constraint::getReferencedTable()
 {
-	return(ref_table);
+	return ref_table;
 }
 
 unsigned Constraint::getColumnCount(unsigned col_type)
 {
 	if(col_type==ReferencedCols)
-		return(ref_columns.size());
+		return ref_columns.size();
 	else
-		return(columns.size());
+		return columns.size();
 }
 
-void Constraint::removeColumns(void)
+void Constraint::removeColumns()
 {
 	setColumnsNotNull(false);
 	columns.clear();
@@ -379,22 +392,22 @@ void Constraint::removeColumn(const QString &name, unsigned col_type)
 	}
 }
 
-DeferralType Constraint::getDeferralType(void)
+DeferralType Constraint::getDeferralType()
 {
-	return(deferral_type);
+	return deferral_type;
 }
 
-bool Constraint::isDeferrable(void)
+bool Constraint::isDeferrable()
 {
-	return(deferrable);
+	return deferrable;
 }
 
-bool Constraint::isNoInherit(void)
+bool Constraint::isNoInherit()
 {
-	return(no_inherit);
+	return no_inherit;
 }
 
-bool Constraint::isReferRelationshipAddedColumn(void)
+bool Constraint::isReferRelationshipAddedColumn()
 {
 	vector<Column *>::iterator itr, itr_end;
 	vector<ExcludeElement>::iterator itr1, itr1_end;
@@ -432,10 +445,10 @@ bool Constraint::isReferRelationshipAddedColumn(void)
 		itr1++;
 	}
 
-	return(found);
+	return found;
 }
 
-vector<Column *> Constraint::getRelationshipAddedColumns(void)
+vector<Column *> Constraint::getRelationshipAddedColumns()
 {
 	Column *column=nullptr;
 	vector<Column *> cols;
@@ -457,12 +470,12 @@ vector<Column *> Constraint::getRelationshipAddedColumns(void)
 			cols.push_back(column);
 	}
 
-	return(cols);
+	return cols;
 }
 
-MatchType Constraint::getMatchType(void)
+MatchType Constraint::getMatchType()
 {
-	return(match_type);
+	return match_type;
 }
 
 
@@ -477,12 +490,12 @@ int Constraint::getExcludeElementIndex(ExcludeElement elem)
 		if(!found) idx++;
 	}
 
-	return(found ? idx : -1);
+	return (found ? idx : -1);
 }
 
-vector<ExcludeElement> Constraint::getExcludeElements(void)
+vector<ExcludeElement> Constraint::getExcludeElements()
 {
-	return(excl_elements);
+	return excl_elements;
 }
 
 void Constraint::addExcludeElements(vector<ExcludeElement> &elems)
@@ -587,7 +600,7 @@ void Constraint::removeExcludeElement(unsigned elem_idx)
 	setCodeInvalidated(true);
 }
 
-void Constraint::removeExcludeElements(void)
+void Constraint::removeExcludeElements()
 {
 	excl_elements.clear();
 	setCodeInvalidated(true);
@@ -610,12 +623,12 @@ ExcludeElement Constraint::getExcludeElement(unsigned elem_idx)
 	if(elem_idx >= excl_elements.size())
 		throw Exception(ErrorCode::RefElementInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
-	return(excl_elements[elem_idx]);
+	return excl_elements[elem_idx];
 }
 
-unsigned Constraint::getExcludeElementCount(void)
+unsigned Constraint::getExcludeElementCount()
 {
-	return(excl_elements.size());
+	return excl_elements.size();
 }
 
 void Constraint::setExcludeElementsAttribute(unsigned def_type)
@@ -638,36 +651,51 @@ void Constraint::setIndexType(IndexingType index_type)
 	this->index_type=index_type;
 }
 
-IndexingType Constraint::getIndexType(void)
+IndexingType Constraint::getIndexType()
 {
-	return(index_type);
+	return index_type;
 }
 
 QString Constraint::getCodeDefinition(unsigned def_type)
 {
-	return(getCodeDefinition(def_type, false));
+	return getCodeDefinition(def_type, false);
 }
 
-void Constraint::setDeclInTableAttribute(void)
+void Constraint::setDeclInTableAttribute()
 {
 	if(!isDeclaredInTable() || (constr_type==ConstraintType::ForeignKey && !isAddedByLinking()))
-		attributes[Attributes::DeclInTable]=QString();
+		attributes[Attributes::DeclInTable]="";
 	else if(!isReferRelationshipAddedColumn() || constr_type==ConstraintType::PrimaryKey)
 		attributes[Attributes::DeclInTable]=Attributes::True;
 }
 
+void Constraint::configureSearchAttributes()
+{
+	QStringList src_col_names, ref_col_names;
+
+	for(auto &col : columns)
+		src_col_names.append(col->getName());
+
+	for(auto &col : ref_columns)
+		ref_col_names.append(col->getName());
+
+	search_attribs[Attributes::SrcColumns] = src_col_names.join(", ");
+	search_attribs[Attributes::RefColumns] = ref_col_names.join(", ");
+	TableObject::configureSearchAttributes();
+}
+
 QString Constraint::getCodeDefinition(unsigned def_type, bool inc_addedbyrel)
 {
 	QString code_def=getCachedCode(def_type, false);
-	if(!inc_addedbyrel && !code_def.isEmpty()) return(code_def);
+	if(!inc_addedbyrel && !code_def.isEmpty()) return code_def;
 
 	QString attrib;
 
-	attributes[Attributes::PkConstr]=QString();
-	attributes[Attributes::FkConstr]=QString();
-	attributes[Attributes::CkConstr]=QString();
-	attributes[Attributes::UqConstr]=QString();
-	attributes[Attributes::ExConstr]=QString();
+	attributes[Attributes::PkConstr]="";
+	attributes[Attributes::FkConstr]="";
+	attributes[Attributes::CkConstr]="";
+	attributes[Attributes::UqConstr]="";
+	attributes[Attributes::ExConstr]="";
 
 	switch(!constr_type)
 	{
@@ -710,9 +738,9 @@ QString Constraint::getCodeDefinition(unsigned def_type, bool inc_addedbyrel)
 			setColumnsAttribute(ReferencedCols, def_type, inc_addedbyrel);
 	}
 
-	attributes[Attributes::RefTable]=(ref_table ? ref_table->getName(true) : QString());
-	attributes[Attributes::Deferrable]=(deferrable ? Attributes::True : QString());
-	attributes[Attributes::NoInherit]=(no_inherit ? Attributes::True : QString());
+	attributes[Attributes::RefTable]=(ref_table ? ref_table->getName(true) : "");
+	attributes[Attributes::Deferrable]=(deferrable ? Attributes::True : "");
+	attributes[Attributes::NoInherit]=(no_inherit ? Attributes::True : "");
 	attributes[Attributes::ComparisonType]=(~match_type);
 	attributes[Attributes::DeferType]=(~deferral_type);
 	attributes[Attributes::IndexType]=(~ index_type);
@@ -725,23 +753,23 @@ QString Constraint::getCodeDefinition(unsigned def_type, bool inc_addedbyrel)
 	if(fill_factor!=0 && (constr_type==ConstraintType::PrimaryKey || constr_type==ConstraintType::Unique))
 		attributes[Attributes::Factor]=QString("%1").arg(fill_factor);
 	else
-		attributes[Attributes::Factor]=QString();
+		attributes[Attributes::Factor]="";
 
-	return(BaseObject::__getCodeDefinition(def_type));
+	return BaseObject::__getCodeDefinition(def_type);
 }
 
 QString Constraint::getDropDefinition(bool cascade)
 {
 	setDeclInTableAttribute();
-	return(TableObject::getDropDefinition(cascade));
+	return TableObject::getDropDefinition(cascade);
 }
 
 QString Constraint::getSignature(bool format)
 {
 	if(!getParentTable())
-		return(BaseObject::getSignature(format));
+		return BaseObject::getSignature(format);
 
-	return(QString("%1 ON %2 ").arg(this->getName(format)).arg(getParentTable()->getSignature(true)));
+	return QString("%1 ON %2 ").arg(this->getName(format)).arg(getParentTable()->getSignature(true));
 }
 
 bool Constraint::isCodeDiffersFrom(BaseObject *object, const vector<QString> &ignored_attribs, const vector<QString> &ignored_tags)
@@ -753,9 +781,9 @@ bool Constraint::isCodeDiffersFrom(BaseObject *object, const vector<QString> &ig
 
 	try
 	{
-		return(BaseObject::isCodeDiffersFrom(this->getCodeDefinition(SchemaParser::XmlDefinition, true),
+		return BaseObject::isCodeDiffersFrom(this->getCodeDefinition(SchemaParser::XmlDefinition, true),
 											 object->getCodeDefinition(SchemaParser::XmlDefinition, true),
-											 ignored_attribs, ignored_tags));
+											 ignored_attribs, ignored_tags);
 	}
 	catch(Exception &e)
 	{
