@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@ Additionally, this class, saves, loads and generates the XML/SQL definition of a
 #include <QFile>
 #include <QObject>
 #include <QStringList>
+#include <QDateTime>
 #include "baseobject.h"
 #include "table.h"
 #include "function.h"
@@ -58,6 +59,8 @@ Additionally, this class, saves, loads and generates the XML/SQL definition of a
 #include "foreignserver.h"
 #include "usermapping.h"
 #include "foreigntable.h"
+#include "transform.h"
+#include "procedure.h"
 #include <algorithm>
 #include <locale.h>
 
@@ -67,12 +70,23 @@ class DatabaseModel:  public QObject, public BaseObject {
 	private:
 		Q_OBJECT
 
+		/*! \brief Stores all changes performed in the database model
+		 * The only purpose of this structure is to be used by the partial diff to filter certain objects by operation/date and,
+		 * differently from OperationList class, it's data persisted in the database model file. */
+		vector<tuple<QDateTime,QString,ObjectType,QString>> changelog;
+
 		/*! \brief Stores the references of all object lists of each type. This map is used by getObjectList() in order
 		 * to return the list according to the provided type */
 		map<ObjectType, vector<BaseObject *> *> obj_lists;
 
 		static unsigned dbmodel_id;
 
+		//! \brief Constants used to access the tuple columns in the internal changelog
+		static constexpr unsigned LogDate = 0,
+		LogSinature = 1,
+		LogObjectType = 2,
+		LogAction = 3;
+
 		XmlParser xmlparser;
 
 		//! \brief Stores the layers names and active layer to write them on XML code
@@ -105,7 +119,10 @@ class DatabaseModel:  public QObject, public BaseObject {
 		bool is_template,
 
 		//! \brief Indicates if the database accepts connection
-		allow_conns;
+		allow_conns,
+
+		//! \brief Indicates if the internal changelog must be saved to the dbm file
+		persist_changelog;
 
 		//! \brief Vectors that stores all the objects types
 		vector<BaseObject *> textboxes,
@@ -136,12 +153,18 @@ class DatabaseModel:  public QObject, public BaseObject {
 		fdata_wrappers,
 		foreign_servers,
 		usermappings,
-		foreign_tables;
+		foreign_tables,
+		transforms,
+		procedures;
 
 		/*! \brief Stores the xml definition for special objects. This map is used
 		 when revalidating the relationships */
 		map<unsigned, QString> xml_special_objs;
 
+		/*! \brief Stores the special objects considered invalid after a relationships revalidation.
+		 * This vector is destroyed only when the model is destroyed too in order to avoid segfaults */
+		vector<BaseObject *> invalid_special_objs;
+
 		//! \brief Indicates if the model is being loaded
 		bool loading_model,
 
@@ -184,7 +207,7 @@ class DatabaseModel:  public QObject, public BaseObject {
 		void createElement(Element &elem, TableObject *tab_obj, BaseObject *parent_obj);
 
 		//! \brief Returns extra error info when loading database models
-		QString getErrorExtraInfo(void);
+		QString getErrorExtraInfo();
 
 		/*! \brief This method forces the indication that the model is being loaded or not by setting the attribute loading_model.
 		 * The attribute loading_model causes the model perform certain operations only when model starts/ends the loading process,
@@ -196,11 +219,64 @@ class DatabaseModel:  public QObject, public BaseObject {
 		//! \brief Set the initial capacity of the objects list for a optimized memory usage
 		void setObjectListsCapacity(unsigned capacity);
 
+		void getViewReferences(BaseObject *object, vector<BaseObject *> &refs, bool exclusion_mode);
+		void getPhysicalTableReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getFunctionReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getSchemaReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getUserDefTypesReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getRoleReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getTablespaceReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getLanguageReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getOpClassReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getOperatorReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getCollationReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getOpFamilyReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getColumnReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getTagReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getSequenceReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getFdwReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+		void getServerReferences(BaseObject *object, vector<BaseObject *> &refs, bool &refer, bool exclusion_mode);
+
+		void getOpClassDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getDomainDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getCastDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getProcedureDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getFunctionDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getAggregateDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getLanguageDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getOperatorDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getRoleDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getRelationshipDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getSequenceDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getColumnDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getTriggerDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getIndexDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getPolicyDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getPhysicalTableDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getTypeDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getViewDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getGenericSQLDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+		void getTransformDependencies(BaseObject *object, vector<BaseObject *> &deps, bool inc_indirect_deps);
+
 	protected:
 		void setLayers(const QStringList &layers);
 		void setActiveLayers(const QList<unsigned> &layers);
-		QStringList getLayers(void);
-		QList<unsigned> getActiveLayers(void);
+		QStringList getLayers();
+		QList<unsigned> getActiveLayers();
+
+		/*! \brief Register an object change in the internal changelog.
+		 * If the provided object is derived from TableObject then the parent is registered instead.
+		 * The op_type is one of the operations Operation::ObjectCreate, Operation::ObjectRemoved, Operation::ObjectModified, any other operation type is ignored.
+		 * This method will validate all the provided parameters and in case of invalid values will raise and exception */
+		void addChangelogEntry(BaseObject *object, unsigned op_type, BaseObject *parent_obj = nullptr);
+
+		/*! \brief Register an object change in the internal changelog.
+		 * This version accepts string parameters to make the changelog loading from file more easy to handle.
+		 * This method will validate all the provided parameters and in case of invalid values will raise and exception */
+		void addChangelogEntry(const QString &signature, const QString &type, const QString &action, const QString &date);
+
+		//! \brief Returns the XML code for the changelog
+		QString getChangelogDefinition();
 
 	public:
 		static constexpr unsigned MetaDbAttributes=1,	//! \brief Handle database model attribute when save/load metadata file
@@ -215,30 +291,31 @@ class DatabaseModel:  public QObject, public BaseObject {
 		MetaTagObjs=512,	//! \brief Handle tags object when save/load metadata file
 		MetaGenericSqlObjs=1024,	//! \brief Handle generic sql object when save/load metadata file
 		MetaObjsAliases=2048,	//! \brief Handle the object's aliases (graphical objects and table children objects) when save/load metadata file
-		MetaAllInfo=4095;	//! \brief Handle all metadata information about objects when save/load metadata file
+		MetaObjsZStackValue=4096,	//! \brief Handle the object's Z stack value
+		MetaAllInfo=8191;	//! \brief Handle all metadata information about objects when save/load metadata file
 
-		DatabaseModel(void);
+		DatabaseModel();
 
 		//! \brief Creates a database model and assign the model widget which will manage this instance
 		explicit DatabaseModel(ModelWidget *model_wgt);
 
-		~DatabaseModel(void);
+		virtual ~DatabaseModel();
 
 		//! \brief Returns the model widget that is managing the current database instance
-		ModelWidget *getModelWidget(void);
+		ModelWidget *getModelWidget();
 
 		//! \brief Returns the complete object list according to the type
 		vector<BaseObject *> *getObjectList(ObjectType obj_type);
 
 		//! \brief Disconnects all the relationships in a ordered way
-		void disconnectRelationships(void);
+		void disconnectRelationships();
 
 		/*! \brief Detects and stores the XML for special objects (that is referencing columns created
 		 by relationship) in order to be reconstructed in a posterior moment */
-		void storeSpecialObjectsXML(void);
+		void storeSpecialObjectsXML();
 
 		//! \brief Validates all the relationship, propagating all column modifications over the tables
-		void validateRelationships(void);
+		void validateRelationships();
 
 		/*! \brief Returns an object seaching it by its name and on the group objects specified by "types".
 		 * If the types list is empty the method will return nullptr. */
@@ -262,9 +339,6 @@ class DatabaseModel:  public QObject, public BaseObject {
 		//! \brief Removes an object from the model
 		void removeObject(BaseObject *object, int obj_idx=-1);
 
-		//! \brief Removes an object using its index and type
-		void removeObject(unsigned obj_idx, ObjectType obj_type);
-
 		//! \brief Returns an object from the model using its index and type
 		BaseObject *getObject(unsigned obj_idx, ObjectType obj_type);
 
@@ -304,45 +378,45 @@ class DatabaseModel:  public QObject, public BaseObject {
 		void setAllowConnections(bool value);
 
 		//! \brief Returns the current state of the sql appeding at end of entire model definition
-		bool isAppendAtEOD(void);
+		bool isAppendAtEOD();
 
 		//! \brief Returns the current state of the sql prepeding at beginning of entire model definition
-		bool isPrependedAtBOD(void);
+		bool isPrependedAtBOD();
 
-		bool isTemplate(void);
+		bool isTemplate();
 
-		bool isAllowConnections(void);
+		bool isAllowConnections();
 
 		//! \brief Destroys all the objects
-		void destroyObjects(void);
+		void destroyObjects();
 
 		//! \brief Returns the object count for the specified type
 		unsigned getObjectCount(ObjectType obj_type);
 
 		//! \brief Returns the object count for all object types.
-		unsigned getObjectCount(void);
+		unsigned getObjectCount();
 
-		unsigned getMaxObjectCount(void);
+		unsigned getMaxObjectCount();
 
 		//! \brief Retuns the specified localization value
 		QString getLocalization(unsigned localiz_id);
 
 		//! \brief Returns the connection limit
-		int getConnectionLimit(void);
+		int getConnectionLimit();
 
 		//! \brief Returns the template database
-		QString getTemplateDB(void);
+		QString getTemplateDB();
 
 		//! \brief Returns the model's author
-		QString getAuthor(void);
+		QString getAuthor();
 
 		//! \brief Returns the database enconding
-		EncodingType getEncoding(void);
+		EncodingType getEncoding();
 
 		BaseObject *getDefaultObject(ObjectType obj_type);
 
 		//! \brief Returns if the model is invalidated. When true its recommended to validate model using Model validation tool
-		bool isInvalidated(void);
+		bool isInvalidated();
 
 		//! \brief Indicate if the model invalidated
 		void setInvalidated(bool value);
@@ -522,6 +596,16 @@ class DatabaseModel:  public QObject, public BaseObject {
 		ForeignTable *getForeignTable(unsigned obj_idx);
 		ForeignTable *getForeignTable(const QString &name);
 
+		void addTransform(Transform *transf, int obj_idx=-1);
+		void removeTransform(Transform *transf, int obj_idx=-1);
+		Transform *getTransform(unsigned obj_idx);
+		Transform *getTransform(const QString &name);
+
+		void addProcedure(Procedure *proc, int obj_idx=-1);
+		void removeProcedure(Procedure *proc, int obj_idx=-1);
+		Procedure *getProcedure(unsigned obj_idx);
+		Procedure *getProcedure(const QString &name);
+
 		void addPermission(Permission *perm);
 		void removePermission(Permission *perm);
 
@@ -546,47 +630,49 @@ class DatabaseModel:  public QObject, public BaseObject {
 		void setBasicAttributes(BaseObject *object);
 
 		void configureDatabase(attribs_map &attribs);
-		PgSqlType createPgSQLType(void);
+		PgSqlType createPgSQLType();
 		BaseObject *createObject(ObjectType obj_type);
-		Role *createRole(void);
-		Tablespace *createTablespace(void);
-		Schema *createSchema(void);
-		Language *createLanguage(void);
-		Function *createFunction(void);
-		Parameter createParameter(void);
-		TypeAttribute createTypeAttribute(void);
-		Type *createType(void);
-		Domain *createDomain(void);
-		Cast *createCast(void);
-		Conversion *createConversion(void);
-		Operator *createOperator(void);
-		OperatorFamily *createOperatorFamily(void);
-		OperatorClass *createOperatorClass(void);
-		Aggregate *createAggregate(void);
-		Table *createTable(void);
-		Column *createColumn(void);
+		Role *createRole();
+		Tablespace *createTablespace();
+		Schema *createSchema();
+		Language *createLanguage();
+		Function *createFunction();
+		Parameter createParameter();
+		TypeAttribute createTypeAttribute();
+		Type *createType();
+		Domain *createDomain();
+		Cast *createCast();
+		Conversion *createConversion();
+		Operator *createOperator();
+		OperatorFamily *createOperatorFamily();
+		OperatorClass *createOperatorClass();
+		Aggregate *createAggregate();
+		Table *createTable();
+		Column *createColumn();
 		Sequence *createSequence(bool ignore_onwer=false);
-		View *createView(void);
-		Collation *createCollation(void);
-		Extension *createExtension(void);
-		Tag *createTag(void);
-		Permission *createPermission(void);
-		Textbox *createTextbox(void);
-		BaseRelationship *createRelationship(void);
+		View *createView();
+		Collation *createCollation();
+		Extension *createExtension();
+		Tag *createTag();
+		Permission *createPermission();
+		Textbox *createTextbox();
+		BaseRelationship *createRelationship();
 		Constraint *createConstraint(BaseObject *parent_obj);
-		Rule *createRule(void);
-		Index *createIndex(void);
-		Trigger *createTrigger(void);
-		Policy *createPolicy(void);
-		EventTrigger *createEventTrigger(void);
-		GenericSQL *createGenericSQL(void);
-		ForeignDataWrapper *createForeignDataWrapper(void);
-		ForeignServer *createForeignServer(void);
-		UserMapping *createUserMapping(void);
-		ForeignTable *createForeignTable(void);
+		Rule *createRule();
+		Index *createIndex();
+		Trigger *createTrigger();
+		Policy *createPolicy();
+		EventTrigger *createEventTrigger();
+		GenericSQL *createGenericSQL();
+		ForeignDataWrapper *createForeignDataWrapper();
+		ForeignServer *createForeignServer();
+		UserMapping *createUserMapping();
+		ForeignTable *createForeignTable();
+		Transform *createTransform();
+		Procedure *createProcedure();
 
 		template<class TableClass>
-		TableClass *createPhysicalTable(void);
+		TableClass *createPhysicalTable();
 
 		//! \brief Update views that reference the provided table forcing the column name deduction and redraw of the former objects
 		void updateViewsReferencingTable(PhysicalTable *table);
@@ -598,7 +684,7 @@ class DatabaseModel:  public QObject, public BaseObject {
 		void updateTableFKRelationships(Table *table);
 
 		//! \brief Updates the fk relationships for all table on the model
-		void updateTablesFKRelationships(void);
+		void updateTablesFKRelationships();
 
 		/*! \brief Validates the removal of the specified column raising errors when the passed object
 		 is still being referecend */
@@ -657,34 +743,62 @@ class DatabaseModel:  public QObject, public BaseObject {
 																		 bool case_sensitive, bool is_regexp, bool exact_match,
 																		 const QString &search_attr = Attributes::Name);
 
+		/*! \brief Returns a list of objects searching them by using the filter syntax [type]:[pattern]:[mode]
+		 * The provided list of filter strings is composed by:
+		 * > The object type (schema name, see BaseObject::getSchemaName())
+		 * > The search pattern itself
+		 * > The pattern mode (regexp | wildcard)
+		 * Additionally the search attribute can be provided so the search may occurr in other attributes instead of the default (name) */
+		vector<BaseObject *> findObjects(const QStringList &filters, const QString &search_attr = Attributes::Name);
+
 		void setLastPosition(const QPoint &pnt);
-		QPoint getLastPosition(void);
+		QPoint getLastPosition();
 
 		void setLastZoomFactor(double zoom);
-		double getLastZoomFactor(void);
+		double getLastZoomFactor();
 
 		/*! \brief This method exposes the XML parser for the outside world. In order to create objects from xml code inside the current
 		 database model you need first get the parser (through this method), populate the parser with the desired XML and then call
 		 the create* method.
 
 		\note: This is not the better approach and certainly will be changed in future releases */
-		XmlParser *getXMLParser(void);
+		XmlParser *getXMLParser();
 
 		//! \brief Returns the ALTER definition between the current model and the provided one
 		virtual QString getAlterDefinition(BaseObject *object) final;
 
 		//! \brief Returns the data dictionary of all tables in a single HTML code
-		void getDataDictionary(attribs_map &datadict, bool browsable, bool splitted);
+		void getDataDictionary(attribs_map &datadict, bool browsable, bool split);
 
 		//! \brief Saves the data dictionary of all tables in a single HTML file or splitted in several files for each table
-		void saveDataDictionary(const QString &path, bool browsable, bool splitted);
+		void saveDataDictionary(const QString &path, bool browsable, bool split);
 
 		/*! \brief Save the graphical objects positions, custom colors and custom points (for relationship lines) to an special file
 				that can be loaded by another model in order to change their objects position */
 		void saveObjectsMetadata(const QString &filename, unsigned options=MetaAllInfo);
 
 		//! \brief Load the file containing the objects positioning to be applied to the model
-		void loadObjectsMetadata(const QString &filename, unsigned options=MetaAllInfo);
+		void loadObjectsMetadata(const QString &filename, unsigned options=MetaAllInfo);		
+
+		/*! \brief Returns a search filter from the objects in the change log.
+		 * It's possible to specify a date interval to contrain the entries
+		 * retrieved from changelog. */
+		QStringList getFiltersFromChangelog(QDateTime start, QDateTime end);
+
+		//! \brief Enable the persistence of the internal changelog
+		void setPersistedChangelog(bool persist);
+
+		//! \brief Returns true when the internal changelog is being persisted to the dbm file
+		bool isPersistedChangelog();
+
+		//! \brief Clears the changelog
+		void clearChangelog();
+
+		//! \brief Returns the last changelog entry date
+		QDateTime getLastChangelogDate();
+
+		//! \brief Returns the amount of entries in the changelog
+		unsigned getChangelogLength();
 
 	signals:
 		//! \brief Signal emitted when a new object is added to the model
@@ -698,7 +812,9 @@ class DatabaseModel:  public QObject, public BaseObject {
 
 	friend class DatabaseImportHelper;
 	friend class ModelWidget;
-	friend class PgModelerCli;
+	friend class PgModelerCliApp;
+	friend class OperationList;
+	friend class PermissionWidget;
 };
 
 #endif
