@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,17 +17,17 @@
 */
 #include "policy.h"
 
-Policy::Policy(void) : TableObject()
+Policy::Policy() : TableObject()
 {
 	obj_type=ObjectType::Policy;
 	permissive = false;
 	policy_cmd = PolicyCmdType::All;
 
-	attributes[Attributes::Permissive] = QString();
-	attributes[Attributes::Command] = QString();
-	attributes[Attributes::UsingExp] = QString();
-	attributes[Attributes::CheckExp] = QString();
-	attributes[Attributes::Roles] = QString();
+	attributes[Attributes::Permissive] = "";
+	attributes[Attributes::Command] = "";
+	attributes[Attributes::UsingExp] = "";
+	attributes[Attributes::CheckExp] = "";
+	attributes[Attributes::Roles] = "";
 }
 
 void Policy::setParentTable(BaseTable *table)
@@ -50,9 +50,9 @@ void Policy::setPermissive(bool value)
 	permissive = value;
 }
 
-bool Policy::isPermissive(void)
+bool Policy::isPermissive()
 {
-	return(permissive);
+	return permissive;
 }
 
 void Policy::setPolicyCommand(PolicyCmdType cmd)
@@ -61,9 +61,9 @@ void Policy::setPolicyCommand(PolicyCmdType cmd)
 	policy_cmd = cmd;
 }
 
-PolicyCmdType Policy::getPolicyCommand(void)
+PolicyCmdType Policy::getPolicyCommand()
 {
-	return(policy_cmd);
+	return policy_cmd;
 }
 
 void Policy::setUsingExpression(const QString &expr)
@@ -72,9 +72,9 @@ void Policy::setUsingExpression(const QString &expr)
 	using_expr = expr;
 }
 
-QString Policy::getUsingExpression(void)
+QString Policy::getUsingExpression()
 {
-	return(using_expr);
+	return using_expr;
 }
 
 void Policy::setCheckExpression(const QString &expr)
@@ -83,9 +83,9 @@ void Policy::setCheckExpression(const QString &expr)
 	check_expr = expr;
 }
 
-QString Policy::getCheckExpression(void)
+QString Policy::getCheckExpression()
 {
-	return(check_expr);
+	return check_expr;
 }
 
 void Policy::addRole(Role *role)
@@ -97,21 +97,21 @@ void Policy::addRole(Role *role)
 		roles.push_back(role);
 }
 
-void Policy::removeRoles(void)
+void Policy::removeRoles()
 {
 	roles.clear();
 	setCodeInvalidated(true);
 }
 
-vector<Role *> Policy::getRoles(void)
+vector<Role *> Policy::getRoles()
 {
-	return(roles);
+	return roles;
 }
 
 QString Policy::getCodeDefinition(unsigned def_type)
 {
 	QString code_def=getCachedCode(def_type, false);
-	if(!code_def.isEmpty()) return(code_def);
+	if(!code_def.isEmpty()) return code_def;
 
 	QStringList rol_names;
 
@@ -123,20 +123,20 @@ QString Policy::getCodeDefinition(unsigned def_type)
 	for(auto role : roles)
 		rol_names.append(role->getName(true));
 
-	attributes[Attributes::Permissive] = (permissive ? Attributes::True : QString());
+	attributes[Attributes::Permissive] = (permissive ? Attributes::True : "");
 	attributes[Attributes::UsingExp] = using_expr;
 	attributes[Attributes::CheckExp] = check_expr;
 	attributes[Attributes::Roles] = rol_names.join(QString(", "));
 
-	return(BaseObject::__getCodeDefinition(def_type));
+	return BaseObject::__getCodeDefinition(def_type);
 }
 
 QString Policy::getSignature(bool format)
 {
 	if(!getParentTable())
-		return(BaseObject::getSignature(format));
+		return BaseObject::getSignature(format);
 
-	return(QString("%1 ON %2").arg(this->getName(format)).arg(getParentTable()->getSignature(true)));
+	return (QString("%1 ON %2").arg(this->getName(format)).arg(getParentTable()->getSignature(true)));
 }
 
 QString Policy::getAlterDefinition(BaseObject *object)
@@ -174,7 +174,7 @@ QString Policy::getAlterDefinition(BaseObject *object)
 			attribs[Attributes::Roles] = aux_rol_names.join(QString(", "));
 
 		copyAttributes(attribs);
-		return(BaseObject::getAlterDefinition(this->getSchemaName(), attributes, false, true));
+		return BaseObject::getAlterDefinition(this->getSchemaName(), attributes, false, true);
 	}
 	catch(Exception &e)
 	{
@@ -184,6 +184,6 @@ QString Policy::getAlterDefinition(BaseObject *object)
 
 bool Policy::isRoleExists(Role *role)
 {
-	if(!role)	return(false);
-	return(std::find(roles.begin(), roles.end(), role) != roles.end());
+	if(!role)	return false;
+	return (std::find(roles.begin(), roles.end(), role) != roles.end());
 }
