@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@ also generates the SQL code definition to represente the table link on PostgreSQ
 #include "baserelationship.h"
 #include "table.h"
 #include "textbox.h"
+#include "pgsqltypes/actiontype.h"
 
 /*
 ### Relationship implementation rules ###
@@ -215,23 +216,23 @@ class Relationship: public BaseRelationship {
 		bool isColumnExists(Column *column);
 
 		//! \brief Executes the column addition for 1-1 relationship
-		void addColumnsRel11(void);
+		void addColumnsRel11();
 
 		//! \brief Executes the column addition for 1-n relationship
-		void addColumnsRel1n(void);
+		void addColumnsRel1n();
 
 		//! \brief Executes the column addition for n-n relationship
-		void addColumnsRelNn(void);
+		void addColumnsRelNn();
 
 		/*! \brief Copy columns from one table to another. This operation is done in
 		 relationships of type copy / generalization. It is necessary
 		 to check duplicate names and incompatible types of columns */
-		void addColumnsRelGenPart(void);
+		void addColumnsRelGenPart();
 
 		/*! \brief Copy constraints from the parent table to the child. Currently, only
 		check constraints are copied only if the NO INHERIT attribute is not set and
 		there are no conflicting constraints (name or expression) on the child table */
-		void addConstraintsRelGenPart(void);
+		void addConstraintsRelGenPart();
 
 		/*! \brief Creates the foreign key that represents the relationship and adds it
 		 to the receiver table. Must be specified the actions ON DELETE and UPDATE. */
@@ -264,7 +265,7 @@ class Relationship: public BaseRelationship {
 		void removeTableObjectsRefCols(PhysicalTable *table);
 
 		//! \brief Creates the special primary key using the names stored in the 'column_ids_pk_rel' vector
-		void createSpecialPrimaryKey(void);
+		void createSpecialPrimaryKey();
 
 		//! \brief Removes all the columns created by the relationship from the specified table primary key if exists.
 		void removeColumnsFromTablePK(PhysicalTable *table);
@@ -279,18 +280,20 @@ class Relationship: public BaseRelationship {
 
 	protected:
 		//! \brief Destroy all the relationship attributes and constraints
-		void destroyObjects(void);
+		void destroyObjects();
 
 		//! \brief Returns all the refenced columns of the relationship
-		vector<Column *> getGeneratedColumns(void);
+		vector<Column *> getGeneratedColumns();
 
 		//! \brief Returns the table generated by the n-n relationship
-		Table *getGeneratedTable(void);
+		Table *getGeneratedTable();
 
 		/*! \brief Returns the generated foreign key that represents the 1-1, 1-n relationship,
 		 as well the primary key generated by the identifier relationship and the
 		 unique key used in 1-1 relationships */
-		vector<Constraint *> getGeneratedConstraints(void);
+		vector<Constraint *> getGeneratedConstraints();
+
+		virtual void configureSearchAttributes();
 
 	public:
 		//! \brief String used as the name suffix separator. Default '_'
@@ -321,7 +324,7 @@ class Relationship: public BaseRelationship {
 					 CopyOptions copy_op = CopyOptions(0,0));
 
 		//! \brief  Connects the relationship making the configuration according to its type
-		void connectRelationship(void);
+		void connectRelationship();
 
 		/*! \brief Disconnects the relationship from the tables removing all the attributes / constraints
 			deallocating all the created object. */
@@ -346,26 +349,26 @@ class Relationship: public BaseRelationship {
 		void setSpecialPrimaryKeyCols(vector<unsigned> &cols);
 
 		//! \brief Returns the column indexes used by the special primary key
-		vector<unsigned> getSpecialPrimaryKeyCols(void);
+		vector<unsigned> getSpecialPrimaryKeyCols();
 
 		//! \brief Defines the name of the auto generated table on the n-n relationship
 		void setTableNameRelNN(const QString &name);
 
 		//! \brief Returns the name of the table auto generated by the n-n relationship
-		QString getTableNameRelNN(void);
+		QString getTableNameRelNN();
 
 		/*! \brief Defines the partition bounding expression associated to the partition table (receiver table)
 		 * when the relationship is connected (only for partitioning relationship) */
 		void setPartitionBoundingExpr(const QString &part_bound_expr);
 
 		//! \brief Returns the partition bouding expression configured for the relationship (only for partitioning relationship)
-		QString getPartitionBoundingExpr(void);
+		QString getPartitionBoundingExpr();
 
 		//! \brief Defines if the created foreign key  is deferrable (only for 1-1, 1-n relationships)
 		void setDeferrable(bool value);
 
 		//! \brief Returns if the created foreign key is deferrable (only for 1-1, 1-n relationships)
-		bool isDeferrable(void);
+		bool isDeferrable();
 
 		//! \brief Defines the deferral type for the created foreign key (only for 1-1, 1-n relationships)
 		void setDeferralType(DeferralType defer_type);
@@ -375,13 +378,13 @@ class Relationship: public BaseRelationship {
 		void setActionType(ActionType act_type, unsigned act_id);
 
 		//! \brief Returns the deferral tyep for the created foreign key (only for 1-1, 1-n relationships)
-		DeferralType getDeferralType(void);
+		DeferralType getDeferralType();
 
 		//! \brief Defines if the relationship is identifier
 		void setIdentifier(bool value);
 
 		//! \brief Returns if the relationship is identifier
-		bool isIdentifier(void);
+		bool isIdentifier();
 
 		//! \brief Set the copy options (only for copy relationships)
 		void setCopyOptions(CopyOptions copy_op);
@@ -393,7 +396,7 @@ class Relationship: public BaseRelationship {
 		QString getNamePattern(unsigned pat_id);
 
 		//! \brief Returns the current copy options
-		CopyOptions getCopyOptions(void);
+		CopyOptions getCopyOptions();
 
 		//! \brief Retuns the action type (ON DELETE or ON UPDATE) of the generated foreign keys
 		ActionType getActionType(unsigned act_id);
@@ -403,13 +406,13 @@ class Relationship: public BaseRelationship {
 			and if in any condition this method returns 'true' indicates that the relationship
 			is no longer valid and must be reconnected. The reconnection operation is
 			made on de model class ​​only because it treats all cases of invalidity at once. */
-		bool isInvalidated(void);
+		bool isInvalidated();
 
 		/*! \brief Forces the relationship to go into invalidated state. This method is useful to invalidate the
 		relationship without add/remove attributes from it. Calling this method will cause the model to revalidate
 		the relationship even it's structure does not reflect an invalid state (see isInvalidate).
 		Use this wisely or it can cause huge slow downs or unexpected results. */
-		void forceInvalidate(void);
+		void forceInvalidate();
 
 		//! \brief Adds an attribute or constaint to the relationship.
 		void addObject(TableObject *tab_obj, int obj_idx=-1);
@@ -439,7 +442,7 @@ class Relationship: public BaseRelationship {
 		Column *getAttribute(const QString &name);
 
 		//! \brief Returns the list of user added attributes
-		vector<TableObject *> getAttributes(void);
+		vector<TableObject *> getAttributes();
 
 		//! \brief Gets an constraint using its index
 		Constraint *getConstraint(unsigned constr_idx);
@@ -448,17 +451,17 @@ class Relationship: public BaseRelationship {
 		Constraint *getConstraint(const QString &name);
 
 		//! \brief Returns the list of user added constraints
-		vector<TableObject *> getConstraints(void);
+		vector<TableObject *> getConstraints();
 
 		/*! \brief Returns the index of a relationship attribute or constraint. Returns -1
 		 when the object doesn't exists */
 		int getObjectIndex(TableObject *object);
 
 		//! \brief Returns the attribute count
-		unsigned getAttributeCount(void);
+		unsigned getAttributeCount();
 
 		//! \brief Returns the constraint count
-		unsigned getConstraintCount(void);
+		unsigned getConstraintCount();
 
 		//! \brief Returns the attribute or constraint count
 		unsigned getObjectCount(ObjectType obj_type);
@@ -468,14 +471,14 @@ class Relationship: public BaseRelationship {
 		 added by the user. This method only scans the list of constraints
 		 on the relationship searching for primary keys created by the user.
 		 If found returns true. */
-		bool hasIndentifierAttribute(void);
+		bool hasIndentifierAttribute();
 
 		/*! \brief Returns table that receives a copy of the columns that represent the relationship
 		 according to its configuration.
 
 		 WARNING: Not necessarily this method returns the destination table this because not in all
 		 relationship configuration the receiver is the destination table */
-		PhysicalTable *getReceiverTable(void);
+		PhysicalTable *getReceiverTable();
 
 		/*! \brief Returns table which serves as a reference when coping the columns to the
 		 receiver table.
@@ -485,11 +488,11 @@ class Relationship: public BaseRelationship {
 
 		 For n-n relationships this method returns nullptr as this type of relationship
 		 has 2 reference tables, which may be obtained by the method BaseRelationship::getTable() */
-		PhysicalTable *getReferenceTable(void);
+		PhysicalTable *getReferenceTable();
 
 		void setSiglePKColumn(bool value);
 
-		bool isSiglePKColumn(void);
+		bool isSiglePKColumn();
 
 		//! \brief Returns SQL / XML definition for the relationship.
 		virtual QString getCodeDefinition(unsigned def_type) final;
@@ -500,16 +503,17 @@ class Relationship: public BaseRelationship {
 		QString getAlterRelationshipDefinition(bool undo_inh_part);
 
 		//! \brief Returns true when the reference table is mandatory in the relationship
-		bool isReferenceTableMandatory(void);
+		bool isReferenceTableMandatory();
 
 		//! \brief Returns true when the receiver table is mandatory in the relationship
-		bool isReceiverTableMandatory(void);
+		bool isReceiverTableMandatory();
 
 		friend class DatabaseModel;
 		friend class ModelWidget;
 		friend class RelationshipWidget;
 		friend class ModelExportHelper;
 		friend class ModelsDiffHelper;
+		friend class ModelDatabaseDiffForm;
 };
 
 #endif
