@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,15 +35,15 @@ class Schema: public BaseGraphicObject {
 		bool rect_visible;
 
 	public:
-		Schema(void);
+		Schema();
 
 		void setName(const QString &name);
 
 		void setFillColor(const QColor &color);
-		QColor getFillColor(void);
+		QColor getFillColor();
 
 		void setRectVisible(bool value);
-		bool isRectVisible(void);
+		bool isRectVisible();
 
 		virtual QString getCodeDefinition(unsigned def_type) final;
 };
