@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ BaseObjectWidget::BaseObjectWidget(QWidget *parent, ObjectType obj_type): QWidge
 	{
 		QSpacerItem *spacer=nullptr;
 
-		setWindowTitle(QString());
+		setWindowTitle("");
 		setupUi(this);
 
 		handled_obj_type=obj_type;
@@ -54,17 +54,14 @@ BaseObjectWidget::BaseObjectWidget(QWidget *parent, ObjectType obj_type): QWidge
 
 		PgModelerUiNs::configureWidgetFont(protected_obj_lbl, PgModelerUiNs::MediumFontFactor);
 
-		connect(edt_perms_tb, SIGNAL(clicked(bool)),this, SLOT(editPermissions(void)));
-		connect(append_sql_tb, SIGNAL(clicked(bool)),this, SLOT(editCustomSQL(void)));
+		connect(edt_perms_tb, SIGNAL(clicked(bool)),this, SLOT(editPermissions()));
+		connect(append_sql_tb, SIGNAL(clicked(bool)),this, SLOT(editCustomSQL()));
 
 		schema_sel=new ObjectSelectorWidget(ObjectType::Schema, true, this);
 		collation_sel=new ObjectSelectorWidget(ObjectType::Collation, true, this);
 		tablespace_sel=new ObjectSelectorWidget(ObjectType::Tablespace, true, this);
 		owner_sel=new ObjectSelectorWidget(ObjectType::Role, true, this);
 
-		alias_ht=new HintTextWidget(alias_hint, this);
-		alias_ht->setText(alias_edt->statusTip());
-
 		baseobject_grid = new QGridLayout;
 		baseobject_grid->setObjectName("objetobase_grid");
 		baseobject_grid->addWidget(protected_obj_frm, 0, 0, 1, 0);
@@ -73,7 +70,6 @@ BaseObjectWidget::BaseObjectWidget(QWidget *parent, ObjectType obj_type): QWidge
 		baseobject_grid->addWidget(id_ico_wgt, 1, 2, 1, 3);
 		baseobject_grid->addWidget(logical_name_lbl, 2, 0, 1, 1);
 		baseobject_grid->addWidget(alias_edt, 2, 1, 1, 1);
-		baseobject_grid->addWidget(alias_hint_wgt, 2, 2, 1, 3);
 		baseobject_grid->addWidget(schema_lbl, 4, 0, 1, 1);
 		baseobject_grid->addWidget(schema_sel, 4, 1, 1, 4);
 		baseobject_grid->addWidget(collation_lbl, 5, 0, 1, 1);
@@ -101,7 +97,7 @@ BaseObjectWidget::BaseObjectWidget(QWidget *parent, ObjectType obj_type): QWidge
 	}
 }
 
-BaseObjectWidget::~BaseObjectWidget(void)
+BaseObjectWidget::~BaseObjectWidget()
 {
 
 }
@@ -113,24 +109,26 @@ bool BaseObjectWidget::eventFilter(QObject *object, QEvent *event)
 	{
 		QKeyEvent *kevent=dynamic_cast<QKeyEvent *>(event);
 
-		if(kevent->key()==Qt::Key_Return || kevent->key()==Qt::Key_Enter)
+		// If the object is protected we avoid accepting the enter hit
+		if(!protected_obj_frm->isVisible() &&
+			 (kevent->key()==Qt::Key_Return || kevent->key()==Qt::Key_Enter))
 		{
 			applyConfiguration();
-			return(true);
+			return true;
 		}
 	}
 
-	return(QWidget::eventFilter(object, event));
+	return QWidget::eventFilter(object, event);
 }
 
-ObjectType BaseObjectWidget::getHandledObjectType(void)
+ObjectType BaseObjectWidget::getHandledObjectType()
 {
-	return(handled_obj_type);
+	return handled_obj_type;
 }
 
-bool BaseObjectWidget::isHandledObjectProtected(void)
+bool BaseObjectWidget::isHandledObjectProtected()
 {
-	return(object_protected);
+	return object_protected;
 }
 
 void BaseObjectWidget::showEvent(QShowEvent *)
@@ -177,8 +175,8 @@ void BaseObjectWidget::setRequiredField(QWidget *widget)
 			}
 		}
 
-		str_aux=(!widget->toolTip().isEmpty() ? QString("\n") : QString());
-		widget->setToolTip(widget->toolTip() + str_aux + trUtf8("Required field. Leaving this empty will raise errors!"));
+		str_aux=(!widget->toolTip().isEmpty() ? QString("\n") : "");
+		widget->setToolTip(widget->toolTip() + str_aux + tr("Required field. Leaving this empty will raise errors!"));
 	}
 }
 
@@ -223,7 +221,7 @@ void BaseObjectWidget::configureTabOrder(vector<QWidget *> widgets)
 	int idx=0, cnt=0;
 
 	widgets.insert(widgets.begin(),
-	{ name_edt, alias_edt, alias_ht, schema_sel , collation_sel, owner_sel, tablespace_sel,
+	{ name_edt, alias_edt, schema_sel , collation_sel, owner_sel, tablespace_sel,
 	  comment_edt, append_sql_tb, edt_perms_tb, disable_sql_chk });
 
 	for(auto &wgt : widgets)
@@ -258,12 +256,12 @@ void BaseObjectWidget::configureTabOrder(vector<QWidget *> widgets)
 		QWidget::setTabOrder(tab_order[idx], tab_order[idx+1]);
 }
 
-BaseObject *BaseObjectWidget::getHandledObject(void)
+BaseObject *BaseObjectWidget::getHandledObject()
 {
-	return(object);
+	return object;
 }
 
-void BaseObjectWidget::cancelChainedOperation(void)
+void BaseObjectWidget::cancelChainedOperation()
 {
 	bool op_list_changed=false;
 
@@ -279,7 +277,7 @@ void BaseObjectWidget::cancelChainedOperation(void)
 	if(new_object && this->object)
 	{
 		if(!op_list_changed)
-			delete(this->object);
+			delete this->object;
 
 		this->object=nullptr;
 	}
@@ -375,8 +373,8 @@ void BaseObjectWidget::setAttributes(DatabaseModel *model, OperationList *op_lis
 		alias_edt->setText(object->getAlias());
 
 		/* When creating a new table or relationship the object is pre allocated and the flag new_object is set.
-	   In order to avoid the selectors to have empty values, we check if the flag is false which means
-	   that the object is not new at all */
+		 * In order to avoid the selectors to have empty values, we check if the flag is false which means
+		 * that the object is not new at all */
 		if(!new_object)
 		{
 			schema_sel->setSelectedObject(object->getSchema());
@@ -451,7 +449,6 @@ void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_typ
 															obj_type!=ObjectType::Parameter);
 
 	alias_edt->setVisible(BaseObject::acceptsAlias(obj_type));
-	alias_hint_wgt->setVisible(BaseObject::acceptsAlias(obj_type));
 	logical_name_lbl->setVisible(BaseObject::acceptsAlias(obj_type));
 
 	edt_perms_tb->setVisible(Permission::acceptsPermission(obj_type));
@@ -480,7 +477,8 @@ void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_typ
 		obj_icon_lbl->setPixmap(QPixmap(PgModelerUiNs::getIconPath(obj_type)));
 		obj_icon_lbl->setToolTip(BaseObject::getTypeName(obj_type));
 
-		if(obj_type!=ObjectType::Permission && obj_type!=ObjectType::Cast && obj_type!=ObjectType::UserMapping)
+		if(obj_type != ObjectType::Permission && obj_type != ObjectType::Cast &&
+			 obj_type != ObjectType::UserMapping && obj_type != ObjectType::Transform)
 		{
 			setRequiredField(name_lbl);
 			setRequiredField(name_edt);
@@ -529,13 +527,13 @@ void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_typ
 QString BaseObjectWidget::generateVersionsInterval(unsigned ver_interv_id, const QString &ini_ver, const QString &end_ver)
 {
 	if(ver_interv_id==UntilVersion && !ini_ver.isEmpty())
-		return(XmlParser::CharLt + QString("= ") + ini_ver);
+		return (XmlParser::CharLt + QString("= ") + ini_ver);
 	else if(ver_interv_id==VersionsInterval && !ini_ver.isEmpty() && !end_ver.isEmpty())
-		return(XmlParser::CharGt + QString("= ") + ini_ver + XmlParser::CharAmp + XmlParser::CharLt + QString("= ") + end_ver);
+		return (XmlParser::CharGt + QString("= ") + ini_ver + XmlParser::CharAmp + XmlParser::CharLt + QString("= ") + end_ver);
 	else if(ver_interv_id==AfterVersion &&  !ini_ver.isEmpty())
-		return(XmlParser::CharGt + QString("= ") + ini_ver);
+		return (XmlParser::CharGt + QString("= ") + ini_ver);
 	else
-		return(QString());
+		return "";
 }
 
 QFrame *BaseObjectWidget::generateInformationFrame(const QString &msg)
@@ -583,7 +581,7 @@ QFrame *BaseObjectWidget::generateInformationFrame(const QString &msg)
 	grid->addWidget(msg_lbl, 0, 1, 1, 1);
 	grid->setContentsMargins(4,4,4,4);
 
-	return(info_frm);
+	return info_frm;
 }
 
 void BaseObjectWidget::highlightVersionSpecificFields(map<QString, vector<QWidget *> > &fields,
@@ -598,7 +596,7 @@ void BaseObjectWidget::highlightVersionSpecificFields(map<QString, vector<QWidge
 		{
 			if(values && values->count(wgt) > 0)
 			{
-				field_name+=QString("<br/>") + trUtf8("Value(s)") + QString(": (");
+				field_name+=QString("<br/>") + tr("Value(s)") + QString(": (");
 				for(auto value : values->at(wgt))
 				{
 					field_name += value;
@@ -610,9 +608,7 @@ void BaseObjectWidget::highlightVersionSpecificFields(map<QString, vector<QWidge
 			}
 
 			wgt->setStyleSheet(QString("QWidget {	font-weight: bold; font-style: italic; color: %1}").arg(color.name()));
-			wgt->setToolTip(QString("<em>") +
-											trUtf8("Version ") +
-											itr.first + QString(" %1</em>").arg(field_name));
+			wgt->setToolTip(QString("<p>PostgreSQL") + itr.first + QString(" %1</p>").arg(field_name));
 		}
 	}
 }
@@ -658,17 +654,17 @@ QFrame *BaseObjectWidget::generateVersionWarningFrame(map<QString, vector<QWidge
 	msg_lbl->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 	msg_lbl->setWordWrap(true);
 
-	msg_lbl->setText(trUtf8("The <em style='color: %1'><strong>highlighted</strong></em> fields in the form or one of their values are available only on specific PostgreSQL versions. \
+	msg_lbl->setText(tr("The <em style='color: %1'><strong>highlighted</strong></em> fields in the form or one of their values are available only on specific PostgreSQL versions. \
 							Generating SQL code for versions other than those specified in the fields' tooltips may create incompatible code.").arg(color.name()));
 
 	grid->addWidget(msg_lbl, 0, 1, 1, 1);
 	grid->setContentsMargins(4,4,4,4);
 
 	alert_frm->adjustSize();
-	return(alert_frm);
+	return alert_frm;
 }
 
-void BaseObjectWidget::editPermissions(void)
+void BaseObjectWidget::editPermissions()
 {
 	BaseObject *parent_obj=nullptr;
 	BaseForm parent_form(this);
@@ -686,7 +682,7 @@ void BaseObjectWidget::editPermissions(void)
 	GeneralConfigWidget::saveWidgetGeometry(&parent_form, permission_wgt->metaObject()->className());
 }
 
-void BaseObjectWidget::editCustomSQL(void)
+void BaseObjectWidget::editCustomSQL()
 {
 	BaseForm parent_form(this);
 	CustomSQLWidget *customsql_wgt=new CustomSQLWidget;
@@ -699,7 +695,7 @@ void BaseObjectWidget::editCustomSQL(void)
 	GeneralConfigWidget::saveWidgetGeometry(&parent_form, customsql_wgt->metaObject()->className());
 }
 
-void BaseObjectWidget::applyConfiguration(void)
+void BaseObjectWidget::applyConfiguration()
 {
 	if(object)
 	{
@@ -806,7 +802,7 @@ void BaseObjectWidget::applyConfiguration(void)
 	}
 }
 
-void BaseObjectWidget::finishConfiguration(void)
+void BaseObjectWidget::finishConfiguration()
 {
 	try
 	{
@@ -904,7 +900,7 @@ void BaseObjectWidget::finishConfiguration(void)
 	}
 }
 
-void BaseObjectWidget::cancelConfiguration(void)
+void BaseObjectWidget::cancelConfiguration()
 {
 	if(!object)
 		return;
@@ -927,7 +923,7 @@ void BaseObjectWidget::cancelConfiguration(void)
 		if(!BaseTable::isBaseTable(obj_type) && obj_type != ObjectType::Relationship)
 		{
 			if(!op_list->isObjectRegistered(this->object, Operation::ObjectCreated))
-				delete(this->object);
+				delete this->object;
 
 			this->object=nullptr;
 		}
@@ -950,7 +946,7 @@ void BaseObjectWidget::cancelConfiguration(void)
 	emit s_objectManipulated();
 }
 
-void BaseObjectWidget::registerNewObject(void)
+void BaseObjectWidget::registerNewObject()
 {
 	try
 	{
