@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,10 +37,10 @@ class CollationWidget: public BaseObjectWidget, public Ui::CollationWidget {
 		void setAttributes(DatabaseModel *model, OperationList *op_list, Schema *schema, Collation *collation);
 		
 	public slots:
-		void applyConfiguration(void);
+		void applyConfiguration();
 		
 	private slots:
-		void resetFields(void);
+		void resetFields();
 };
 
 #endif
