@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -43,10 +43,11 @@ class ColumnWidget: public BaseObjectWidget, public Ui::ColumnWidget {
 		void setAttributes(DatabaseModel *model, OperationList *op_list, BaseObject *parent_obj, Column *column);
 		
 	private slots:
-		void editSequenceAttributes(void);
-		
+		void editSequenceAttributes();
+		void enableDefaultValueFields();
+
 	public slots:
-		void applyConfiguration(void);
+		void applyConfiguration();
 };
 
 #endif
