@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -56,20 +56,20 @@ class ConfigurationForm: public QDialog, public Ui::ConfigurationForm {
 		PluginsConfWgt=5;
 		
 		ConfigurationForm(QWidget * parent = nullptr, Qt::WindowFlags f = Qt::Widget);
-		~ConfigurationForm(void);
+		virtual ~ConfigurationForm();
 		
 		BaseConfigWidget *getConfigurationWidget(unsigned idx);
 		
 	public slots:
-		void applyConfiguration(void);
-		void loadConfiguration(void);
-		void reject(void);
+		void applyConfiguration();
+		void loadConfiguration();
+		void reject();
 		
 	private slots:
-		void restoreDefaults(void);
+		void restoreDefaults();
 
 	signals:
-		void s_invalidateModelsRequested(void);
+		void s_invalidateModelsRequested();
 };
 
 #endif
