@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, Ob
 		excl_elems_grp->setLayout(grid);
 
 		expression_hl=new SyntaxHighlighter(expression_txt, false, true);
-		expression_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
+		expression_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 
 		columns_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^
 										  (ObjectsTableWidget::EditButton |
@@ -51,16 +51,16 @@ ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, Ob
 		ref_table_sel=new ObjectSelectorWidget(ObjectType::Table, true, this);
 
 		columns_tab->setColumnCount(2);
-		columns_tab->setHeaderLabel(trUtf8("Column"), 0);
+		columns_tab->setHeaderLabel(tr("Column"), 0);
 		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("column")),0);
-		columns_tab->setHeaderLabel(trUtf8("Type"), 1);
+		columns_tab->setHeaderLabel(tr("Type"), 1);
 		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		ref_columns_tab->setEnabled(false);
 		ref_columns_tab->setColumnCount(2);
-		ref_columns_tab->setHeaderLabel(trUtf8("Column"), 0);
+		ref_columns_tab->setHeaderLabel(tr("Column"), 0);
 		ref_columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("column")),0);
-		ref_columns_tab->setHeaderLabel(trUtf8("Type"), 1);
+		ref_columns_tab->setHeaderLabel(tr("Type"), 1);
 		ref_columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		dynamic_cast<QGridLayout *>(columns_tbw->widget(0)->layout())->addWidget(columns_tab, 1,0,1,3);
@@ -69,23 +69,16 @@ ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, Ob
 
 		configureFormLayout(constraint_grid, ObjectType::Constraint);
 
-		ConstraintType::getTypes(list);
-		constr_type_cmb->addItems(list);
+		constr_type_cmb->addItems(ConstraintType::getTypes());
+		match_cmb->addItems(MatchType::getTypes());
+		deferral_cmb->addItems(DeferralType::getTypes());
+		indexing_cmb->addItems(IndexingType::getTypes());
 
-		MatchType::getTypes(list);
-		match_cmb->addItems(list);
-
-		DeferralType::getTypes(list);
-		deferral_cmb->addItems(list);
-
-		ActionType::getTypes(list);
+		list = ActionType::getTypes();
 		on_delete_cmb->addItems(list);
 		on_update_cmb->addItems(list);
 
-		IndexingType::getTypes(list);
-		indexing_cmb->addItems(list);
-
-		info_frm=generateInformationFrame(trUtf8("Columns which were included by relationship can not be added / removed manually from the primary key. If done such changes they can raise errors. To create primary key using columns included by relationship use the following options: identifier field, attributes & constraints tab or primary key tab on the relationship form."));
+		info_frm=generateInformationFrame(tr("Columns which were included by relationship can not be added / removed manually from the primary key. If done such changes they can raise errors. To create primary key using columns included by relationship use the following options: identifier field, attributes & constraints tab or primary key tab on the relationship form."));
 		constraint_grid->addWidget(info_frm, constraint_grid->count()+1, 0, 1, 0);
 		info_frm->setParent(this);
 
@@ -97,19 +90,18 @@ ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, Ob
 		constraint_grid->addWidget(warn_frm, constraint_grid->count()+1, 0, 1, 0);
 		warn_frm->setParent(this);
 
-		//connect(parent_form->apply_ok_btn,SIGNAL(clicked(bool)), this, SLOT(applyConfiguration(void)));
-		connect(constr_type_cmb, SIGNAL(currentIndexChanged(int)), this, SLOT(selectConstraintType(void)));
+		connect(constr_type_cmb, SIGNAL(currentIndexChanged(int)), this, SLOT(selectConstraintType()));
 		connect(deferrable_chk, SIGNAL(toggled(bool)), deferral_cmb, SLOT(setEnabled(bool)));
 		connect(deferrable_chk, SIGNAL(toggled(bool)), deferral_lbl, SLOT(setEnabled(bool)));
 		connect(indexing_chk, SIGNAL(toggled(bool)), indexing_cmb, SLOT(setEnabled(bool)));
 		connect(columns_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addColumn(int)));
 		connect(columns_tab, SIGNAL(s_rowRemoved(int)), this, SLOT(removeColumn(int)));
-		connect(columns_tab, SIGNAL(s_rowsRemoved(void)), this, SLOT(removeColumns(void)));
+		connect(columns_tab, SIGNAL(s_rowsRemoved()), this, SLOT(removeColumns()));
 		connect(ref_columns_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addColumn(int)));
 		connect(ref_columns_tab, SIGNAL(s_rowRemoved(int)), this, SLOT(removeColumn(int)));
-		connect(ref_columns_tab, SIGNAL(s_rowsRemoved(void)), this, SLOT(removeColumns(void)));
-		connect(ref_table_sel, SIGNAL(s_selectorCleared(void)), this, SLOT(selectReferencedTable(void)));
-		connect(ref_table_sel, SIGNAL(s_objectSelected(void)), this, SLOT(selectReferencedTable(void)));
+		connect(ref_columns_tab, SIGNAL(s_rowsRemoved()), this, SLOT(removeColumns()));
+		connect(ref_table_sel, SIGNAL(s_selectorCleared()), this, SLOT(selectReferencedTable()));
+		connect(ref_table_sel, SIGNAL(s_objectSelected()), this, SLOT(selectReferencedTable()));
 		connect(fill_factor_chk, SIGNAL(toggled(bool)), fill_factor_sb, SLOT(setEnabled(bool)));
 
 		selectConstraintType();
@@ -173,7 +165,7 @@ void ConstraintWidget::removeColumn(int)
 		updateColumnsCombo(Constraint::ReferencedCols);
 }
 
-void ConstraintWidget::removeColumns(void)
+void ConstraintWidget::removeColumns()
 {
 	if(sender()==columns_tab)
 		updateColumnsCombo(Constraint::SourceCols);
@@ -275,7 +267,7 @@ void ConstraintWidget::updateColumnsCombo(unsigned col_id)
 	}
 }
 
-void ConstraintWidget::selectReferencedTable(void)
+void ConstraintWidget::selectReferencedTable()
 {
 	Table *table=dynamic_cast<Table *>(ref_table_sel->getSelectedObject());
 
@@ -296,7 +288,7 @@ void ConstraintWidget::selectReferencedTable(void)
 	}
 }
 
-void ConstraintWidget::selectConstraintType(void)
+void ConstraintWidget::selectConstraintType()
 {
 	ConstraintType constr_type=ConstraintType(constr_type_cmb->currentText());
 
@@ -434,7 +426,7 @@ void ConstraintWidget::setAttributes(DatabaseModel *model, OperationList *op_lis
 	excl_elems_tab->setElements<ExcludeElement>(excl_elems);
 }
 
-void ConstraintWidget::applyConfiguration(void)
+void ConstraintWidget::applyConfiguration()
 {
 	try
 	{
@@ -504,8 +496,10 @@ void ConstraintWidget::applyConfiguration(void)
 
 		finishConfiguration();
 
-		//For the foreign keys, updates the fk relationships on the model
-		if(constr->getConstraintType()==ConstraintType::ForeignKey)
+		//For the foreign keys and uniques, updates the fk relationships on the model
+		if(this->table &&
+			 (constr->getConstraintType()==ConstraintType::ForeignKey ||
+			 constr->getConstraintType()==ConstraintType::Unique))
 			this->model->updateTableFKRelationships(dynamic_cast<Table *>(this->table));
 	}
 	catch(Exception &e)
