@@ -6,7 +6,7 @@ ModelExportHelper::ModelExportHelper(QObject *parent) : QObject(parent)
 	resetExportParams();
 }
 
-void ModelExportHelper::resetExportParams(void)
+void ModelExportHelper::resetExportParams()
 {
 	sql_gen_progress=progress=0;
 	db_created=ignore_dup=drop_db=drop_objs=export_canceled=false;
@@ -71,12 +71,12 @@ void ModelExportHelper::exportToSQL(DatabaseModel *db_model, const QString &file
 		progress=sql_gen_progress=0;
 		BaseObject::setPgSQLVersion(pgsql_ver);
 		emit s_progressUpdated(progress,
-							   trUtf8("Generating SQL code for PostgreSQL `%1'").arg(BaseObject::getPgSQLVersion()),
+							   tr("Generating SQL code for PostgreSQL `%1'").arg(BaseObject::getPgSQLVersion()),
 							   ObjectType::BaseObject);
 		progress=1;
 		db_model->saveModel(filename, SchemaParser::SqlDefinition);
 
-		emit s_progressUpdated(100, trUtf8("Output SQL file `%1' successfully written.").arg(filename), ObjectType::BaseObject);
+		emit s_progressUpdated(100, tr("Output SQL file `%1' successfully written.").arg(filename), ObjectType::BaseObject);
 		emit s_exportFinished();
 	}
 	catch(Exception &e)
@@ -200,7 +200,7 @@ void ModelExportHelper::exportToPNG(ObjectsScene *scene, const QString &filename
 			painter.setRenderHint(QPainter::SmoothPixmapTransform, true);
 
 			emit s_progressUpdated((page_idx/static_cast<double>(pages.size())) * 90,
-														 trUtf8("Rendering objects to page %1/%2.").arg(page_idx).arg(pages.size()), ObjectType::BaseObject);
+														 tr("Rendering objects to page %1/%2.").arg(page_idx).arg(pages.size()), ObjectType::BaseObject);
 
 			//Render the entire viewport onto the pixmap
 			view->render(&painter, QRectF(QPointF(0,0), pix.size()), retv);
@@ -227,14 +227,14 @@ void ModelExportHelper::exportToPNG(ObjectsScene *scene, const QString &filename
 
 		if(!export_canceled)
 		{
-			emit s_progressUpdated(100, trUtf8("Output image `%1' successfully written.").arg(filename), ObjectType::BaseObject);
+			emit s_progressUpdated(100, tr("Output image `%1' successfully written.").arg(filename), ObjectType::BaseObject);
 			emit s_exportFinished();
 		}
 		else
 			emit s_exportCanceled();
 
 		if(view!=viewp)
-			delete(view);
+			delete view;
 	}
 	catch(Exception &e)
 	{
@@ -262,15 +262,15 @@ void ModelExportHelper::exportToSVG(ObjectsScene *scene, const QString &filename
 	ObjectsScene::setGridOptions(show_grid, false, show_delim);
 	scene->update();
 
-	emit s_progressUpdated(0, trUtf8("Exporting model to SVG file."));
+	emit s_progressUpdated(0, tr("Exporting model to SVG file."));
 
 	svg_gen.setFileName(filename);
-	svg_gen.setTitle(trUtf8("SVG representation of database model"));
-	svg_gen.setDescription(trUtf8("SVG file generated by pgModeler"));
+	svg_gen.setTitle(tr("SVG representation of database model"));
+	svg_gen.setDescription(tr("SVG file generated by pgModeler"));
 
 	QPainter *painter=new QPainter(&svg_gen);
 	scene->render(painter, QRectF(0, 0, scene_rect.size().width(), scene_rect.size().height()), scene_rect);
-	delete(painter);
+	delete painter;
 
 	//Restoring the scene settings
 	ObjectsScene::setGridOptions(shw_grd, align_objs, shw_dlm);
@@ -299,16 +299,16 @@ void ModelExportHelper::exportToSVG(ObjectsScene *scene, const QString &filename
 		/* Removing the empty (transparent) backgound object in order to save some space in the file if
 		the grid or delimiter is displayed */
 		if(!show_delim && !show_grid)
-			svg_def.replace(QRegExp("(<image)(.)*(xlink:href)(=)(\")(\\w|=|/|\\+|:|;|,|\n)+(\")( )+(/>)"), QString());
+			svg_def.replace(QRegExp("(<image)(.)*(xlink:href)(=)(\")(\\w|=|/|\\+|:|;|,|\n)+(\")( )+(/>)"), "");
 
-		buf.append(svg_def);
+		buf.append(svg_def.toUtf8());
 
 		svg_file.open(QFile::WriteOnly | QFile::Truncate);
 		svg_file.write(buf);
 		svg_file.close();
 	}
 
-	emit s_progressUpdated(100, trUtf8("Output file `%1' successfully written.").arg(filename), ObjectType::BaseObject);
+	emit s_progressUpdated(100, tr("Output file `%1' successfully written.").arg(filename), ObjectType::BaseObject);
 	emit s_exportFinished();
 }
 
@@ -348,51 +348,55 @@ void ModelExportHelper::exportToDBMS(DatabaseModel *db_model, Connection conn, c
 		conn.connect();
 		version=conn.getPgSQLVersion(true);
 
-		emit s_progressUpdated(progress, trUtf8("Starting export to DBMS."));
+		emit s_progressUpdated(progress, tr("Starting export to DBMS."));
 
 		//Overriding the DBMS version case the version is informed on parameter
 		if(!pgsql_ver.isEmpty())
 		{
 			BaseObject::setPgSQLVersion(pgsql_ver);
-			emit s_progressUpdated(progress, trUtf8("PostgreSQL version detection overridden. Using version `%1'.").arg(pgsql_ver));
+			emit s_progressUpdated(progress, tr("PostgreSQL version detection overridden. Using version `%1'.").arg(pgsql_ver));
 		}
 		else
 		{
 			BaseObject::setPgSQLVersion(version);
-			emit s_progressUpdated(progress, trUtf8("PostgreSQL `%1' server detected.").arg(version));
+			emit s_progressUpdated(progress, tr("PostgreSQL `%1' server detected.").arg(version));
 		}
 
 		if(simulate && use_tmp_names)
 		{
-			emit s_progressUpdated(progress, trUtf8("Generating temporary names for database, roles and tablespaces."));
+			emit s_progressUpdated(progress, tr("Generating temporary names for database, roles and tablespaces."));
 			generateTempObjectNames(db_model);
 		}
 		else if(use_tmp_names)
 			throw Exception(ErrorCode::InvUsageTempNamesExportOption,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
-
-		if(simulate && db_model->isSQLDisabled())
+		if(db_model->isSQLDisabled())
 		{
-			db_model->setSQLDisabled(false);
-			db_sql_reenabled=true;
-			emit s_progressUpdated(progress, trUtf8("Enabling the SQL code for database `%1' to avoid errors.").arg(db_model->getName()));
+			if(simulate)
+			{
+				db_model->setSQLDisabled(false);
+				db_sql_reenabled=true;
+				emit s_progressUpdated(progress, tr("Enabling the SQL code for database `%1' to avoid errors.").arg(db_model->getName()));
+			}
+			else
+				throw Exception(Exception::getErrorMessage(ErrorCode::ExportFailureDbSQLDisabled).arg(db_model->getName()),
+												ErrorCode::ExportFailureDbSQLDisabled, __PRETTY_FUNCTION__, __FILE__, __LINE__);
 		}
 
-
 		if(ignore_dup)
 		{
-			emit s_progressUpdated(progress, trUtf8("Ignoring object duplication errors."));
+			emit s_progressUpdated(progress, tr("Ignoring object duplication errors."));
 
 			//Save the current status for ALTER command generation for table columns/constraints
 			saveGenAtlerCmdsStatus(db_model);
 		}
 
 		if(!ignored_errors.isEmpty())
-			emit s_progressUpdated(progress, trUtf8("Ignoring the following error code(s): `%1'.").arg(ignored_errors.join(", ")));
+			emit s_progressUpdated(progress, tr("Ignoring the following error code(s): `%1'.").arg(ignored_errors.join(", ")));
 
 		if(drop_db)
 		{
-			emit s_progressUpdated(progress, trUtf8("Trying to drop database `%1'.").arg(db_model->getName()));
+			emit s_progressUpdated(progress, tr("Trying to drop database `%1'.").arg(db_model->getName()));
 
 			try
 			{
@@ -408,7 +412,7 @@ void ModelExportHelper::exportToDBMS(DatabaseModel *db_model, Connection conn, c
 		}
 
 		if(simulate)
-			emit s_progressUpdated(progress, trUtf8("Simulation mode activated."));
+			emit s_progressUpdated(progress, tr("Simulation mode activated."));
 
 		//Creates the roles and tablespaces separately from the other objects
 		for(type_id=0; type_id < 2 && !export_canceled; type_id++)
@@ -426,10 +430,8 @@ void ModelExportHelper::exportToDBMS(DatabaseModel *db_model, Connection conn, c
 					{
 						//Emits a signal indicating that the object is being exported
 						emit s_progressUpdated(progress,
-											   trUtf8("Creating object `%1' (%2)")
-											   .arg(object->getName())
-											   .arg(object->getTypeName()),
-											   object->getObjectType());
+																	 tr("Creating object `%1' (%2)").arg(object->getName()).arg(object->getTypeName()),
+																	 object->getObjectType());
 
 						sql_cmd=object->getCodeDefinition(SchemaParser::SqlDefinition);
 
@@ -471,9 +473,8 @@ void ModelExportHelper::exportToDBMS(DatabaseModel *db_model, Connection conn, c
 
 				//Creating the database on the DBMS
 				emit s_progressUpdated(progress,
-									   trUtf8("Creating database `%1'")
-									   .arg(db_model->getName()),
-									   ObjectType::Database);
+															 tr("Creating database `%1'").arg(db_model->getName()),
+															 ObjectType::Database);
 
 				sql_cmd=db_model->__getCodeDefinition(SchemaParser::SqlDefinition);
 				pos = comm_regexp.indexIn(sql_cmd);
@@ -505,14 +506,14 @@ void ModelExportHelper::exportToDBMS(DatabaseModel *db_model, Connection conn, c
 			new_db_conn=conn;
 			new_db_conn.setConnectionParam(Connection::ParamDbName, db_model->getName());
 			emit s_progressUpdated(progress,
-								   trUtf8("Connecting to database `%1'")
+								   tr("Connecting to database `%1'")
 								   .arg(db_model->getName()));
 
 			new_db_conn.connect();
 			progress=30;
 
 			//Creating the other object types
-			emit s_progressUpdated(progress, trUtf8("Generating SQL for `%1' objects...").arg(db_model->getObjectCount()));
+			emit s_progressUpdated(progress, tr("Generating SQL for `%1' objects...").arg(db_model->getObjectCount()));
 
 			//Exporting the database model definition using the opened connection
 			buf=db_model->getCodeDefinition(SchemaParser::SqlDefinition, false);
@@ -560,7 +561,7 @@ void ModelExportHelper::exportToDBMS(DatabaseModel *db_model, Connection conn, c
 		conn.close();
 
 		/* When running in a separated thread (other than the main application thread)
-	redirects the error in form of signal */
+		 * redirects the error in form of signal */
 		if(this->thread() && this->thread()!=qApp->thread())
 		{
 			errors.push_back(e);
@@ -591,12 +592,12 @@ void ModelExportHelper::exportToDataDict(DatabaseModel *db_model, const QString
 	{
 		progress=0;
 		emit s_progressUpdated(progress,
-													 trUtf8("Starting data dictionary generation..."),
+													 tr("Starting data dictionary generation..."),
 													 ObjectType::BaseObject);
 		progress=1;
 		db_model->saveDataDictionary(path, browsable, splitted);
 
-		emit s_progressUpdated(100, trUtf8("Data dictionary successfully saved into `%1'.").arg(path), ObjectType::BaseObject);
+		emit s_progressUpdated(100, tr("Data dictionary successfully saved into `%1'.").arg(path), ObjectType::BaseObject);
 		emit s_exportFinished();
 	}
 	catch(Exception &e)
@@ -649,7 +650,7 @@ void ModelExportHelper::saveGenAtlerCmdsStatus(DatabaseModel *db_model)
 	}
 }
 
-void ModelExportHelper::restoreGenAtlerCmdsStatus(void)
+void ModelExportHelper::restoreGenAtlerCmdsStatus()
 {
 	for(auto &itr : alter_cmds_status)
 		itr.first->setGenerateAlterCmds(itr.second);
@@ -667,7 +668,7 @@ void ModelExportHelper::undoDBMSExport(DatabaseModel *db_model, Connection &conn
 	//In case of error during the export all created object are removed
 	if(db_created || created_objs[ObjectType::Role] >= 0 || created_objs[ObjectType::Tablespace] >= 0)
 	{
-		emit s_progressUpdated(99, trUtf8("Destroying objects created on the server."));
+		emit s_progressUpdated(99, tr("Destroying objects created on the server."));
 
 		//Dropping the database
 		if(db_created)
@@ -693,7 +694,7 @@ void ModelExportHelper::undoDBMSExport(DatabaseModel *db_model, Connection &conn
 
 		if(use_tmp_names)
 		{
-			emit s_progressUpdated(100, trUtf8("Restoring original names of database, roles and tablespaces."));
+			emit s_progressUpdated(100, tr("Restoring original names of database, roles and tablespaces."));
 			restoreObjectNames();
 		}
 	}
@@ -743,7 +744,7 @@ void ModelExportHelper::generateTempObjectNames(DatabaseModel *db_model)
 		obj.first->setName(tmp_name.mid(0,15));
 		tmp_name.clear();
 
-		emit s_progressUpdated(progress, trUtf8("Renaming `%1' (%2) to `%3'")
+		emit s_progressUpdated(progress, tr("Renaming `%1' (%2) to `%3'")
 							   .arg(old_name)
 							   .arg(obj.first->getTypeName())
 							   .arg(obj.first->getName()));
@@ -754,7 +755,7 @@ void ModelExportHelper::generateTempObjectNames(DatabaseModel *db_model)
 	db_model->setCodesInvalidated();
 }
 
-void ModelExportHelper::restoreObjectNames(void)
+void ModelExportHelper::restoreObjectNames()
 {
 	for(auto &obj : orig_obj_names)
 		obj.first->setName(obj.second);
@@ -782,7 +783,7 @@ bool ModelExportHelper::isDuplicationError(const QString &error_code)
 									QString("42P07"), QString("42710"), QString("42701"),
 									QString("42P16")};
 
-	return(err_codes.contains(error_code));
+	return err_codes.contains(error_code);
 }
 
 void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &conn, bool drop_objs)
@@ -813,7 +814,8 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 																 ObjectType::Conversion, ObjectType::Cast,	ObjectType::Language,
 																 ObjectType::Collation, ObjectType::Extension, ObjectType::Type,
 																 ObjectType::EventTrigger, ObjectType::ForeignDataWrapper, ObjectType::ForeignServer,
-																 ObjectType::UserMapping, ObjectType::ForeignTable, ObjectType::Database, ObjectType::BaseObject };
+																 ObjectType::UserMapping, ObjectType::ForeignTable, ObjectType::Transform,
+																 ObjectType::Procedure, ObjectType::Database, ObjectType::BaseObject };
 
 	/* Extract each SQL command from the buffer and execute them separately. This is done
    to permit the user, in case of error, identify what object is wrongly configured. */
@@ -901,9 +903,9 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 					obj_name=tab_name + QString(".") + obj_name;
 
 					if(is_drop)
-						msg=trUtf8("Dropping object `%1' (%2)").arg(obj_name).arg(BaseObject::getTypeName(obj_type));
+						msg=tr("Dropping object `%1' (%2)").arg(obj_name).arg(BaseObject::getTypeName(obj_type));
 					else
-						msg=trUtf8("Creating object `%1' (%2)").arg(obj_name).arg(BaseObject::getTypeName(obj_type));
+						msg=tr("Creating object `%1' (%2)").arg(obj_name).arg(BaseObject::getTypeName(obj_type));
 
 					emit s_progressUpdated(aux_prog, msg, obj_type, sql_cmd);
 					is_drop=false;
@@ -920,6 +922,7 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 
 						obj_type=obj_tp;
 
+						//Removing/replacing noisy keywords in order to extract more easily the object's name
 						if(lin.startsWith(QString("CREATE")) || lin.startsWith(QString("ALTER")))
 						{
 							if(obj_tp==ObjectType::Index)
@@ -936,10 +939,16 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 							{
 								lin.remove(QString("UNLOGGED"));
 							}
-							else if(obj_tp==ObjectType::Function)
+							else if(obj_tp==ObjectType::Function || obj_tp==ObjectType::Procedure)
 							{
 								lin.remove(QString("OR REPLACE"));
 							}
+							else if(obj_tp==ObjectType::Transform)
+							{
+								lin.remove(QString(" FOR"));
+								lin.replace(QString(" LANGUAGE "), "_");
+								lin.replace(QRegExp("(TRANSFORM)(.)+(\\.)"), "TRANSFORM ");
+							}
 						}
 						else if(lin.startsWith(QString("DROP")))
 						{
@@ -969,7 +978,7 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 									int spc_idx=lin.indexOf(' ');
 									obj_name=lin.mid(0, (spc_idx >= 0 ? spc_idx + 1 : lin.size()));
 
-									if(obj_tp!=ObjectType::Function)
+									if(obj_tp!=ObjectType::Function && obj_tp!=ObjectType::Procedure)
 									{
 										obj_name=obj_name.remove('(').simplified();
 										obj_name=obj_name.remove(')').simplified();
@@ -989,11 +998,11 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 								obj_name.remove(';');
 
 								if(is_create)
-									msg=trUtf8("Creating object `%1' (%2)").arg(obj_name).arg(obj_tp_name);
+									msg=tr("Creating object `%1' (%2)").arg(obj_name).arg(obj_tp_name);
 								else if(is_drop)
-									msg=trUtf8("Dropping object `%1' (%2)").arg(obj_name).arg(obj_tp_name);
+									msg=tr("Dropping object `%1' (%2)").arg(obj_name).arg(obj_tp_name);
 								else
-									msg=trUtf8("Changing object `%1' (%2)").arg(obj_name).arg(obj_tp_name);
+									msg=tr("Changing object `%1' (%2)").arg(obj_name).arg(obj_tp_name);
 							}
 							// If the type of the object being create can't be identified
 							else
@@ -1007,7 +1016,7 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 								else
 									aux_cmd_type = QString("ALTER");
 
-								msg=trUtf8("Running auxiliary `%1' command...").arg(aux_cmd_type);
+								msg=tr("Running auxiliary `%1' command...").arg(aux_cmd_type);
 							}
 
 							break;
@@ -1021,7 +1030,7 @@ void ModelExportHelper::exportBufferToDBMS(const QString &buffer, Connection &co
 				else if(!sql_cmd.trimmed().isEmpty())
 				{
 					//General commands like grant, revoke or set aren't explicitly shown
-					emit s_progressUpdated(aux_prog, trUtf8("Running auxiliary command."), ObjectType::BaseObject, sql_cmd);
+					emit s_progressUpdated(aux_prog, tr("Running auxiliary command."), ObjectType::BaseObject, sql_cmd);
 				}
 
 				//Executes the extracted SQL command
@@ -1131,7 +1140,7 @@ void ModelExportHelper::setExportToDataDictParams(DatabaseModel *db_model, const
 	this->splitted=splitted;
 }
 
-void ModelExportHelper::exportToDBMS(void)
+void ModelExportHelper::exportToDBMS()
 {
 	if(connection)
 	{
@@ -1152,7 +1161,7 @@ void ModelExportHelper::exportToDBMS(void)
 	}
 }
 
-void ModelExportHelper::exportToPNG(void)
+void ModelExportHelper::exportToPNG()
 {
 	try
 	{
@@ -1165,7 +1174,7 @@ void ModelExportHelper::exportToPNG(void)
 	}
 }
 
-void ModelExportHelper::exportToSVG(void)
+void ModelExportHelper::exportToSVG()
 {
 	try
 	{
@@ -1178,7 +1187,7 @@ void ModelExportHelper::exportToSVG(void)
 	}
 }
 
-void ModelExportHelper::exportToSQL(void)
+void ModelExportHelper::exportToSQL()
 {
 	try
 	{
@@ -1191,7 +1200,7 @@ void ModelExportHelper::exportToSQL(void)
 	}
 }
 
-void ModelExportHelper::exportToDataDict(void)
+void ModelExportHelper::exportToDataDict()
 {
 	try
 	{
@@ -1204,7 +1213,7 @@ void ModelExportHelper::exportToDataDict(void)
 	}
 }
 
-void ModelExportHelper::cancelExport(void)
+void ModelExportHelper::cancelExport()
 {
 	export_canceled=true;
 }
