@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,10 +26,14 @@ ModelValidationWidget::ModelValidationWidget(QWidget *parent): QWidget(parent)
 	{
 		setupUi(this);
 
+		output_menu.addAction(tr("Copy as text"), this, SLOT(copyTextOutput()), QKeySequence("Ctrl+Shift+C"));
+		output_menu.addAction(tr("Clear"), this, SLOT(clearOutput()));
+		output_btn->setMenu(&output_menu);
+
 		htmlitem_del=new HtmlItemDelegate(this);
 		output_trw->setItemDelegateForColumn(0, htmlitem_del);
 
-		version_cmb->addItem(trUtf8("Autodetect"));
+		version_cmb->addItem(tr("Autodetect"));
 		version_cmb->addItems(PgSqlVersions::AllVersions);
 
 		options_frm->setVisible(false);
@@ -39,23 +43,16 @@ ModelValidationWidget::ModelValidationWidget(QWidget *parent): QWidget(parent)
 		validation_helper=nullptr;
 		this->setModel(nullptr);
 
-		sql_validation_ht=new HintTextWidget(sql_validation_hint, this);
-		sql_validation_ht->setText(sql_validation_chk->statusTip());
-
-		use_unique_names_ht=new HintTextWidget(use_unique_names_hint, this);
-		use_unique_names_ht->setText(use_tmp_names_chk->statusTip());
-
-		connect(hide_tb, SIGNAL(clicked(void)), this, SLOT(hide(void)));
-		connect(clear_btn, SIGNAL(clicked(void)), this, SLOT(clearOutput(void)));
+		connect(hide_tb, SIGNAL(clicked()), this, SLOT(hide()));
 		connect(options_btn, SIGNAL(toggled(bool)), options_frm, SLOT(setVisible(bool)));
 		connect(sql_validation_chk, SIGNAL(toggled(bool)), connections_cmb, SLOT(setEnabled(bool)));
 		connect(sql_validation_chk, SIGNAL(toggled(bool)), version_cmb, SLOT(setEnabled(bool)));
 		connect(sql_validation_chk, SIGNAL(toggled(bool)), use_tmp_names_chk, SLOT(setEnabled(bool)));
-		connect(validate_btn, SIGNAL(clicked(void)), this, SLOT(validateModel(void)));
-		connect(fix_btn, SIGNAL(clicked(void)), this, SLOT(applyFixes(void)));
-		connect(cancel_btn, SIGNAL(clicked(void)), this, SLOT(cancelValidation(void)));
+		connect(validate_btn, SIGNAL(clicked()), this, SLOT(validateModel()));
+		connect(fix_btn, SIGNAL(clicked()), this, SLOT(applyFixes()));
+		connect(cancel_btn, SIGNAL(clicked()), this, SLOT(cancelValidation()));
 		connect(connections_cmb, SIGNAL(activated(int)), this, SLOT(editConnections()));
-		connect(swap_ids_btn, SIGNAL(clicked(void)), this, SLOT(swapObjectsIds(void)));
+		connect(swap_ids_btn, SIGNAL(clicked()), this, SLOT(swapObjectsIds()));
 
 		connect(sql_validation_chk, &QCheckBox::toggled, [&](){
 			configureValidation();
@@ -105,10 +102,10 @@ bool ModelValidationWidget::eventFilter(QObject *object, QEvent *event)
 		}
 	}
 
-	return(QWidget::eventFilter(object, event));
+	return QWidget::eventFilter(object, event);
 }
 
-void ModelValidationWidget::createThread(void)
+void ModelValidationWidget::createThread()
 {
 	if(!validation_thread)
 	{
@@ -124,20 +121,20 @@ void ModelValidationWidget::createThread(void)
 			output_trw->setUniformRowHeights(false);
 		});
 
-		connect(validation_thread, SIGNAL(started(void)), validation_helper, SLOT(validateModel(void)));
-		connect(validation_thread, SIGNAL(started(void)), validation_helper, SLOT(applyFixes(void)));
-		connect(validation_thread, SIGNAL(finished(void)), this, SLOT(updateGraphicalObjects(void)));
-		connect(validation_thread, SIGNAL(finished(void)), this, SLOT(destroyThread(void)));
+		connect(validation_thread, SIGNAL(started()), validation_helper, SLOT(validateModel()));
+		connect(validation_thread, SIGNAL(started()), validation_helper, SLOT(applyFixes()));
+		connect(validation_thread, SIGNAL(finished()), this, SLOT(updateGraphicalObjects()));
+		connect(validation_thread, SIGNAL(finished()), this, SLOT(destroyThread()));
 
 		connect(validation_helper, SIGNAL(s_validationInfoGenerated(ValidationInfo)), this, SLOT(updateValidation(ValidationInfo)), Qt::QueuedConnection);
 		connect(validation_helper, SIGNAL(s_progressUpdated(int,QString,ObjectType,QString,bool)), this, SLOT(updateProgress(int,QString,ObjectType,QString,bool)), Qt::BlockingQueuedConnection);
 		connect(validation_helper, SIGNAL(s_objectProcessed(QString,ObjectType)), this, SLOT(updateObjectName(QString,ObjectType)), Qt::QueuedConnection);
-		connect(validation_helper, SIGNAL(s_validationFinished(void)), this, SLOT(reenableValidation(void)), Qt::QueuedConnection);
-		connect(validation_helper, SIGNAL(s_validationCanceled(void)), this, SLOT(reenableValidation(void)), Qt::QueuedConnection);
-		connect(validation_helper, SIGNAL(s_sqlValidationStarted(void)), this, SLOT(handleSQLValidationStarted(void)), Qt::QueuedConnection);
-		connect(validation_helper, SIGNAL(s_fixApplied(void)), this, SLOT(clearOutput(void)), Qt::QueuedConnection);
-		connect(validation_helper, SIGNAL(s_fixApplied(void)), prog_info_wgt, SLOT(show(void)), Qt::QueuedConnection);
-		connect(validation_helper, SIGNAL(s_relsValidationRequested(void)), this, SLOT(validateRelationships(void)));
+		connect(validation_helper, SIGNAL(s_validationFinished()), this, SLOT(reenableValidation()), Qt::QueuedConnection);
+		connect(validation_helper, SIGNAL(s_validationCanceled()), this, SLOT(reenableValidation()), Qt::QueuedConnection);
+		connect(validation_helper, SIGNAL(s_sqlValidationStarted()), this, SLOT(handleSQLValidationStarted()), Qt::QueuedConnection);
+		connect(validation_helper, SIGNAL(s_fixApplied()), this, SLOT(clearOutput()), Qt::QueuedConnection);
+		connect(validation_helper, SIGNAL(s_fixApplied()), prog_info_wgt, SLOT(show()), Qt::QueuedConnection);
+		connect(validation_helper, SIGNAL(s_relsValidationRequested()), this, SLOT(validateRelationships()));
 
 		connect(validation_helper, &ModelValidationHelper::s_validationCanceled, [&](){
 			emit s_validationCanceled();
@@ -159,20 +156,20 @@ void ModelValidationWidget::destroyThread(bool force)
 	if(validation_thread && (force || validation_helper->getErrorCount()==0))
 	{
 		validation_thread->wait();
-		delete(validation_thread);
-		delete(validation_helper);
+		delete validation_thread;
+		delete validation_helper;
 		validation_thread=nullptr;
 		validation_helper=nullptr;
 	}
 }
 
-void ModelValidationWidget::hide(void)
+void ModelValidationWidget::hide()
 {
 	QWidget::hide();
 	emit s_visibilityChanged(false);
 }
 
-void ModelValidationWidget::reenableValidation(void)
+void ModelValidationWidget::reenableValidation()
 {
 	if(!validation_helper->isInFixMode())
 	{
@@ -181,7 +178,7 @@ void ModelValidationWidget::reenableValidation(void)
 		validate_btn->setEnabled(true);
 		cancel_btn->setEnabled(false);
 		fix_btn->setEnabled(model_wgt->getDatabaseModel()->isInvalidated());
-		clear_btn->setEnabled(true);
+		output_btn->setEnabled(true);
 		options_btn->setEnabled(true);
 		options_frm->setEnabled(true);
 		ico_lbl->setVisible(false);
@@ -192,7 +189,7 @@ void ModelValidationWidget::reenableValidation(void)
 	}
 }
 
-void ModelValidationWidget::emitValidationInProgress(void)
+void ModelValidationWidget::emitValidationInProgress()
 {
 	clearOutput();
 	emit s_validationInProgress(true);
@@ -208,10 +205,10 @@ void ModelValidationWidget::emitValidationInProgress(void)
 	swap_ids_btn->setEnabled(false);
 }
 
-void ModelValidationWidget::clearOutput(void)
+void ModelValidationWidget::clearOutput()
 {
 	output_trw->clear();
-	clear_btn->setEnabled(false);
+	output_btn->setEnabled(false);
 	prog_info_wgt->setVisible(false);
 	fix_btn->setEnabled(false);
 	validation_prog_pb->setValue(0);
@@ -221,7 +218,7 @@ void ModelValidationWidget::clearOutput(void)
 	error_count_lbl->setText(QString("%1").arg(0));
 }
 
-void ModelValidationWidget::cancelValidation(void)
+void ModelValidationWidget::cancelValidation()
 {
 	validation_helper->cancelValidation();
 	validation_thread->quit();
@@ -244,9 +241,9 @@ void ModelValidationWidget::setModel(ModelWidget *model_wgt)
 	destroyThread(true);
 }
 
-bool ModelValidationWidget::isValidationRunning(void)
+bool ModelValidationWidget::isValidationRunning()
 {
-	return(validation_thread && validation_thread->isRunning());
+	return (validation_thread && validation_thread->isRunning());
 }
 
 void ModelValidationWidget::updateValidation(ValidationInfo val_info)
@@ -269,7 +266,7 @@ void ModelValidationWidget::updateValidation(ValidationInfo val_info)
 	label->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
 	if(val_info.getValidationType()==ValidationInfo::BrokenReference)
-		label->setText(trUtf8("The object <strong>%1</strong> <em>(%2)</em> [id: %3] is being referenced by <strong>%4</strong> object(s) before its creation.")
+		label->setText(tr("The object <strong>%1</strong> <em>(%2)</em> [id: %3] is being referenced by <strong>%4</strong> object(s) before its creation.")
 					   .arg(val_info.getObject()->getName(true).remove('"'))
 					   .arg(val_info.getObject()->getTypeName())
 					   .arg(val_info.getObject()->getObjectId())
@@ -284,7 +281,7 @@ void ModelValidationWidget::updateValidation(ValidationInfo val_info)
 			str_aux=QString(" owned by table <strong>%1</strong> ").arg(tab_obj->getParentTable()->getName(true).remove('"'));
 		}
 
-		label->setText(trUtf8("The object <strong>%1</strong> <em>(%2)</em> [id: %3]%4 is referencing columns created by <strong>%5</strong> relationship(s) but is created before them.")
+		label->setText(tr("The object <strong>%1</strong> <em>(%2)</em> [id: %3]%4 is referencing columns created by <strong>%5</strong> relationship(s) but is created before them.")
 					   .arg(val_info.getObject()->getName(true).remove('"'))
 					   .arg(val_info.getObject()->getTypeName())
 					   .arg(val_info.getObject()->getObjectId())
@@ -303,23 +300,23 @@ void ModelValidationWidget::updateValidation(ValidationInfo val_info)
 		else
 			ref_name=val_info.getObject()->getName(true).remove('"');
 
-		label->setText(trUtf8("The object <strong>%1</strong> <em>(%2)</em> has a name that conflicts with <strong>%3</strong> object name(s).")
+		label->setText(tr("The object <strong>%1</strong> <em>(%2)</em> has a name that conflicts with <strong>%3</strong> object name(s).")
 					   .arg(ref_name)
 					   .arg(val_info.getObject()->getTypeName())
 					   .arg(val_info.getReferences().size()));
 
 	}
 	else if(val_info.getValidationType()==ValidationInfo::BrokenRelConfig)
-		label->setText(trUtf8("The relationship <strong>%1</strong> [id: %2] is in a permanent invalidation state and needs to be relocated.")
+		label->setText(tr("The relationship <strong>%1</strong> [id: %2] is in a permanent invalidation state and needs to be relocated.")
 					   .arg(val_info.getObject()->getName(true).remove('"'))
 					   .arg(val_info.getObject()->getObjectId()));
 	else if(val_info.getValidationType()==ValidationInfo::SqlValidationError)
-		label->setText(trUtf8("SQL validation failed due to the error(s) below. <strong>NOTE:</strong><em> Errors during SQL validation don't invalidate the model but may affect operations like <strong>export</strong> and <strong>diff</strong>.</em>"));
+		label->setText(tr("SQL validation failed due to the error(s) below. <strong>NOTE:</strong><em> Errors during SQL validation don't invalidate the model but may affect operations like <strong>export</strong> and <strong>diff</strong>.</em>"));
 	else if(val_info.getValidationType() == ValidationInfo::MissingExtension)
 	{
 		Column *col = dynamic_cast<Column *>(val_info.getObject());
 
-		label->setText(trUtf8("The column <strong>%1</strong> on <strong>%2</strong> <em>(%3)</em> is referencing the geospatial data type <strong>%4</strong> but the <strong>postgis</strong> extension is not present in the model!")
+		label->setText(tr("The column <strong>%1</strong> on <strong>%2</strong> <em>(%3)</em> is referencing the geospatial data type <strong>%4</strong> but the <strong>postgis</strong> extension is not present in the model!")
 									 .arg(col->getName())
 									 .arg(col->getParentTable()->getSignature(true))
 									 .arg(BaseObject::getTypeName(ObjectType::Table))
@@ -361,12 +358,12 @@ void ModelValidationWidget::updateValidation(ValidationInfo val_info)
 
 		if(val_info.getValidationType()==ValidationInfo::BrokenRelConfig)
 		{
-			PgModelerUiNs::createOutputTreeItem(output_trw, trUtf8("<strong>HINT:</strong> try to swap the relationship by another ones that somehow are linked to it through generated columns or constraints to solve this issue. Note that other objects may be lost in the swap process."),
+			PgModelerUiNs::createOutputTreeItem(output_trw, tr("<strong>HINT:</strong> try to swap the relationship by another ones that somehow are linked to it through generated columns or constraints to solve this issue. Note that other objects may be lost in the swap process."),
 												QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")), item);
 		}
 		else if(val_info.getValidationType()==ValidationInfo::MissingExtension)
 		{
-			PgModelerUiNs::createOutputTreeItem(output_trw, trUtf8("<strong>HINT:</strong> Create the extension in the model or let it be created by applying the needed fixes."),
+			PgModelerUiNs::createOutputTreeItem(output_trw, tr("<strong>HINT:</strong> Create the extension in the model or let it be created by applying the needed fixes."),
 																					QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")), item);
 		}
 		else
@@ -407,25 +404,25 @@ void ModelValidationWidget::updateValidation(ValidationInfo val_info)
 							label2->setTextInteractionFlags(Qt::TextSelectableByMouse);
 							pal.setColor(QPalette::Text, QColor(255,0,0));
 							label2->setPalette(pal);
-							label2->setText(trUtf8("<em>The above object was created by a relationship. Change the name pattern on it's generator relationship. Fix will not be applied!</em>"));
+							label2->setText(tr("<em>The above object was created by a relationship. Change the name pattern on it's generator relationship. Fix will not be applied!</em>"));
 							output_trw->setItemWidget(item2, 0, label2);
 							item1->setExpanded(true);
 						}
 					}
 
-					label1->setText(trUtf8("Conflicting object: <strong>%1</strong> <em>(%2)</em>.")
+					label1->setText(tr("Conflicting object: <strong>%1</strong> <em>(%2)</em>.")
 									.arg(ref_name.remove('"'))
 									.arg(ref_obj->getTypeName()));
 				}
 				else
 				{
 					if(val_info.getValidationType()==ValidationInfo::SpObjBrokenReference)
-						label1->setText(trUtf8("Relationship: <strong>%1</strong> [id: %2].")
+						label1->setText(tr("Relationship: <strong>%1</strong> [id: %2].")
 										.arg(ref_name.remove('"'))
 										.arg(ref_obj->getObjectId()));
 					else
 					{
-						label1->setText(trUtf8("Referrer object: <strong>%1</strong> <em>(%2)</em> [id: %3].")
+						label1->setText(tr("Referrer object: <strong>%1</strong> <em>(%2)</em> [id: %3].")
 										.arg(ref_name.remove('"'))
 										.arg(ref_obj->getTypeName())
 										.arg(ref_obj->getObjectId()));
@@ -448,14 +445,14 @@ void ModelValidationWidget::updateValidation(ValidationInfo val_info)
 	error_lbl->setEnabled(validation_helper->getErrorCount() > 0);
 	warn_count_lbl->setText(QString("%1").arg(validation_helper->getWarningCount()));
 	error_count_lbl->setText(QString("%1").arg(validation_helper->getErrorCount()));
-	output_trw->setItemHidden(item, false);
+	item->setHidden(false);
 	output_trw->scrollToBottom();
 
 	if(val_info.getValidationType()==ValidationInfo::SqlValidationError)
 		emit s_validationFinished(validation_helper->getErrorCount() != 0);
 }
 
-void ModelValidationWidget::validateModel(void)
+void ModelValidationWidget::validateModel()
 {
 	createThread();
 	configureValidation();
@@ -464,13 +461,13 @@ void ModelValidationWidget::validateModel(void)
 	validation_thread->start();
 }
 
-void ModelValidationWidget::applyFixes(void)
+void ModelValidationWidget::applyFixes()
 {
 	emitValidationInProgress();
 	validation_helper->switchToFixMode(true);
-	disconnect(validation_thread, SIGNAL(started(void)), validation_helper, SLOT(validateModel(void)));
+	disconnect(validation_thread, SIGNAL(started()), validation_helper, SLOT(validateModel()));
 	validation_thread->start();
-	connect(validation_thread, SIGNAL(started(void)), validation_helper, SLOT(validateModel(void)));
+	connect(validation_thread, SIGNAL(started()), validation_helper, SLOT(validateModel()));
 }
 
 void ModelValidationWidget::updateProgress(int prog, QString msg, ObjectType obj_type, QString cmd, bool is_code_gen)
@@ -496,7 +493,7 @@ void ModelValidationWidget::updateProgress(int prog, QString msg, ObjectType obj
 			warn_lbl->setEnabled(true);
 			warn_count_lbl->setText(QString::number(1));
 			PgModelerUiNs::createOutputTreeItem(output_trw,
-												trUtf8("SQL validation not executed! No connection defined."),
+												tr("SQL validation not executed! No connection defined."),
 												QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")));
 		}		
 		else
@@ -506,7 +503,7 @@ void ModelValidationWidget::updateProgress(int prog, QString msg, ObjectType obj
 		}
 
 		PgModelerUiNs::createOutputTreeItem(output_trw,
-											trUtf8("Database model successfully validated."),
+											tr("Database model successfully validated."),
 											QPixmap(PgModelerUiNs::getIconPath("msgbox_info")));
 
 		emit s_validationFinished(validation_helper->getErrorCount() != 0);
@@ -532,7 +529,7 @@ void ModelValidationWidget::updateProgress(int prog, QString msg, ObjectType obj
 		else
 		{
 			ico_lbl->setPixmap(QPixmap(PgModelerUiNs::getIconPath("codigosql")));
-			object_lbl->setText(trUtf8("Running SQL commands on server..."));
+			object_lbl->setText(tr("Running SQL commands on server..."));
 
 			item=PgModelerUiNs::createOutputTreeItem(output_trw, msg, ico, nullptr, false);
 
@@ -544,11 +541,11 @@ void ModelValidationWidget::updateProgress(int prog, QString msg, ObjectType obj
 
 void ModelValidationWidget::updateObjectName(QString obj_name, ObjectType obj_type)
 {
-	object_lbl->setText(trUtf8("Processing object: %1").arg(PgModelerUiNs::formatMessage(obj_name)));
+	object_lbl->setText(tr("Processing object: %1").arg(PgModelerUiNs::formatMessage(obj_name)));
 	ico_lbl->setPixmap(QPixmap(PgModelerUiNs::getIconPath(obj_type)));
 }
 
-void ModelValidationWidget::configureValidation(void)
+void ModelValidationWidget::configureValidation()
 {
 	if(model_wgt && validation_helper)
 	{
@@ -559,7 +556,7 @@ void ModelValidationWidget::configureValidation(void)
 		if(sql_validation_chk->isChecked() && connections_cmb->currentIndex() > 0 && connections_cmb->currentIndex()!=connections_cmb->count()-1)
 		{
 			conn=reinterpret_cast<Connection *>(connections_cmb->itemData(connections_cmb->currentIndex()).value<void *>());
-			ver=(version_cmb->currentIndex() > 0 ? version_cmb->currentText() : QString());
+			ver=(version_cmb->currentIndex() > 0 ? version_cmb->currentText() : "");
 		}
 
 		validation_helper->setValidationParams(model_wgt->getDatabaseModel(), conn, ver, use_tmp_names_chk->isChecked());
@@ -577,14 +574,14 @@ void ModelValidationWidget::resizeEvent(QResizeEvent *event)
 	{
 		validate_btn->setToolButtonStyle(style);
 		fix_btn->setToolButtonStyle(style);
-		clear_btn->setToolButtonStyle(style);
+		output_btn->setToolButtonStyle(style);
 		cancel_btn->setToolButtonStyle(style);
 		options_btn->setToolButtonStyle(style);
 		swap_ids_btn->setToolButtonStyle(style);
 	}
 }
 
-void ModelValidationWidget::validateRelationships(void)
+void ModelValidationWidget::validateRelationships()
 {
 	try
 	{
@@ -598,7 +595,7 @@ void ModelValidationWidget::validateRelationships(void)
 	}
 }
 
-void ModelValidationWidget::updateGraphicalObjects(void)
+void ModelValidationWidget::updateGraphicalObjects()
 {
 	if(!graph_objects.empty())
 	{
@@ -618,7 +615,7 @@ void ModelValidationWidget::updateGraphicalObjects(void)
 	}
 }
 
-void ModelValidationWidget::editConnections(void)
+void ModelValidationWidget::editConnections()
 {
 	if(connections_cmb->currentIndex()==connections_cmb->count()-1)
 	{
@@ -627,37 +624,74 @@ void ModelValidationWidget::editConnections(void)
 	}
 }
 
-void ModelValidationWidget::handleSQLValidationStarted(void)
+void ModelValidationWidget::handleSQLValidationStarted()
 {
 	options_btn->setEnabled(false);
-	clear_btn->setEnabled(false);
+	output_btn->setEnabled(false);
 	options_frm->setEnabled(false);
 }
 
-void ModelValidationWidget::swapObjectsIds(void)
+void ModelValidationWidget::swapObjectsIds()
 {
-	BaseForm parent_form(this);
-	SwapObjectsIdsWidget *swap_ids_wgt=new SwapObjectsIdsWidget;
-	swap_ids_wgt->setModel(model_wgt->getDatabaseModel());
-	parent_form.setMainWidget(swap_ids_wgt);
-
-	GeneralConfigWidget::restoreWidgetGeometry(&parent_form, swap_ids_wgt->metaObject()->className());
-	parent_form.exec();
-	GeneralConfigWidget::saveWidgetGeometry(&parent_form, swap_ids_wgt->metaObject()->className());
+	if(model_wgt)
+		model_wgt->swapObjectsIds();
 }
 
-void ModelValidationWidget::selectObject(void)
+void ModelValidationWidget::selectObject()
 {
 	QTreeWidgetItem *item = output_trw->currentItem();
 
-	if(item && !validation_thread->isRunning())
+	if(item && validation_thread && !validation_thread->isRunning())
 	{
 		BaseObject *selected_obj=reinterpret_cast<BaseObject *>(item->data(1, Qt::UserRole).value<void *>());
 
 		if(selected_obj && QApplication::mouseButtons() == Qt::RightButton)
 		{
-			model_wgt->configureObjectMenu(selected_obj);
+			model_wgt->configurePopupMenu(selected_obj);
 			model_wgt->showObjectMenu();
 		}
 	}
 }
+
+void ModelValidationWidget::copyTextOutput()
+{
+	qApp->clipboard()->setText(generateOutputText());
+}
+
+QString ModelValidationWidget::generateOutputText()
+{
+	QString output;
+	QTreeWidgetItem *item = nullptr;
+
+	for(int idx = 0; idx < output_trw->topLevelItemCount(); idx ++)
+	{
+		item = output_trw->topLevelItem(idx);
+		generateOutputItemText(item, output, 0);
+		output += '\n';
+	}
+
+	return output;
+}
+
+void ModelValidationWidget::generateOutputItemText(QTreeWidgetItem *item, QString &output, int level)
+{
+	if(!item)	return;
+
+	QLabel *label = dynamic_cast<QLabel *>(item->treeWidget()->itemWidget(item, 0));
+	QString text,
+			filler = "\n" + QString().fill(' ', level * 2);
+
+	text = item->text(0);
+
+	if(label && text.isEmpty())
+		text = label->text();
+
+	text.replace(QRegExp("(\\<)(\\/)?(br|strong|em)(\\/)?(\\>)"), "");
+	text.prepend(level == 0 ? "* " : "\n");
+
+	text.replace("\n", filler);
+	output += text;
+
+	for(int child = 0; child < item->childCount(); child++)
+		generateOutputItemText(item->child(child), output, level + 1);
+}
