@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class NewObjectOverlayWidget: public QWidget, public Ui::NewObjectOverlayWidget
 	public:
 		explicit NewObjectOverlayWidget(ModelWidget * parent);
 		void setSelectedObjects(vector<BaseObject *> &sel_objs);
-		void configureOverlayButtons(void);
+		void configureOverlayButtons();
 };
 
 #endif
