@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,13 +39,13 @@ class ParameterWidget: public BaseObjectWidget, public Ui::ParameterWidget {
 	public:
 		ParameterWidget(QWidget * parent = nullptr);
 		void setAttributes(Parameter parameter, DatabaseModel *model);
-		Parameter getParameter(void);
+		Parameter getParameter();
 
 	public slots:
-		void applyConfiguration(void);
+		void applyConfiguration();
 
 	private slots:
-		void enableVariadic(void);
+		void enableVariadic();
 };
 
 #endif
