@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,36 +38,18 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 									 src_fk_pattern_txt, dst_fk_pattern_txt,
 									 pk_pattern_txt, uq_pattern_txt, pk_col_pattern_txt };
 
-		gen_tab_name_ht=new HintTextWidget(gen_tab_name_hint, this);
-		gen_tab_name_ht->setText(relnn_tab_name_edt->statusTip());
-
-		ref_table_ht=new HintTextWidget(ref_table_hint, this);
-		recv_table_ht=new HintTextWidget(recv_table_hint, this);
-
-		identifier_ht=new HintTextWidget(identifier_hint, this);
-		identifier_ht->setText(identifier_chk->statusTip());
-
-		single_pk_ht=new HintTextWidget(single_pk_hint, this);
-		single_pk_ht->setText(single_pk_chk->statusTip());
-
-		default_part_ht=new HintTextWidget(default_part_hint, this);
-		default_part_ht->setText(default_part_chk->statusTip());
-
 		table1_hl=nullptr;
 		table1_hl=new SyntaxHighlighter(ref_table_txt, true);
-		table1_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
+		table1_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 
 		table2_hl=nullptr;
 		table2_hl=new SyntaxHighlighter(recv_table_txt, true);
-		table2_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
+		table2_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 
 		for(int i=0; i < pattern_fields.size(); i++)
 		{
 			patterns_hl[i]=new SyntaxHighlighter(qobject_cast<QPlainTextEdit *>(pattern_fields[i]), true);
-			patterns_hl[i]->loadConfiguration(GlobalAttributes::ConfigurationsDir +
-											  GlobalAttributes::DirSeparator +
-											  GlobalAttributes::PatternHighlightConf +
-											  GlobalAttributes::ConfigurationExt);
+			patterns_hl[i]->loadConfiguration(GlobalAttributes::getConfigurationFilePath(GlobalAttributes::PatternHighlightConf));
 		}
 
 		attributes_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^
@@ -81,21 +63,21 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 		advanced_objs_tab=new ObjectsTableWidget(ObjectsTableWidget::EditButton, true, this);
 
 		attributes_tab->setColumnCount(2);
-		attributes_tab->setHeaderLabel(trUtf8("Attribute"), 0);
+		attributes_tab->setHeaderLabel(tr("Attribute"), 0);
 		attributes_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("column")),0);
-		attributes_tab->setHeaderLabel(trUtf8("Type"), 1);
+		attributes_tab->setHeaderLabel(tr("Type"), 1);
 		attributes_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		constraints_tab->setColumnCount(2);
-		constraints_tab->setHeaderLabel(trUtf8("Constraint"), 0);
+		constraints_tab->setHeaderLabel(tr("Constraint"), 0);
 		constraints_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("constraint")),0);
-		constraints_tab->setHeaderLabel(trUtf8("Type"), 1);
+		constraints_tab->setHeaderLabel(tr("Type"), 1);
 		constraints_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		advanced_objs_tab->setColumnCount(2);
-		advanced_objs_tab->setHeaderLabel(trUtf8("Name"), 0);
+		advanced_objs_tab->setHeaderLabel(tr("Name"), 0);
 		advanced_objs_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("column")),0);
-		advanced_objs_tab->setHeaderLabel(trUtf8("Type"), 1);
+		advanced_objs_tab->setHeaderLabel(tr("Type"), 1);
 		advanced_objs_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		connect(advanced_objs_tab, SIGNAL(s_rowEdited(int)), this, SLOT(showAdvancedObject(int)));
@@ -111,7 +93,7 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 		rel_attribs_tbw->widget(ConstraintsTab)->setLayout(grid);
 
 		grid=dynamic_cast<QGridLayout *>(rel_attribs_tbw->widget(SpecialPkTab)->layout());
-		frame=generateInformationFrame(trUtf8("Use the special primary key if you want to include a primary key containing generated columns to the receiver table. <strong>Important:</strong> if this is a new relationship there is a need to finish its creation and reopen this dialog to create the special primary key."));
+		frame=generateInformationFrame(tr("Use the special primary key if you want to include a primary key containing generated columns to the receiver table. <strong>Important:</strong> if this is a new relationship there is a need to finish its creation and reopen this dialog to create the special primary key."));
 
 		grid->addWidget(frame, 1, 0, 1, 1);
 		frame->setParent(rel_attribs_tbw->widget(SpecialPkTab));
@@ -121,7 +103,7 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 
 		grid->addWidget(advanced_objs_tab, 0, 0, 1, 1);
 
-		frame=generateInformationFrame(trUtf8("This advanced tab shows the objects (columns or table) auto created by the relationship's connection as well the foreign keys that represents the link between the participant tables."));
+		frame=generateInformationFrame(tr("This advanced tab shows the objects (columns or table) auto created by the relationship's connection as well the foreign keys that represents the link between the participant tables."));
 		grid->addWidget(frame, 1, 0, 1, 1);
 
 		rel_attribs_tbw->widget(AdvancedTab)->setLayout(grid);
@@ -133,10 +115,9 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 
 		configureFormLayout(relationship_grid, ObjectType::Relationship);
 
-		DeferralType::getTypes(list);
-		deferral_cmb->addItems(list);
+		deferral_cmb->addItems(DeferralType::getTypes());
 
-		frame=generateInformationFrame(trUtf8("Available tokens to define name patterns:<br/>\
+		frame=generateInformationFrame(tr("Available tokens to define name patterns:<br/>\
 					<strong>%1</strong> = Reference (source) primary key column name. <em>(Ignored on constraint patterns)</em><br/> \
 					<strong>%2</strong> = Reference (source) table name.<br/> \
 					<strong>%3</strong> = Receiver (destination) table name.<br/> \
@@ -148,8 +129,8 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 		vlayout=dynamic_cast<QVBoxLayout *>(name_patterns_grp->layout());
 		vlayout->addWidget(frame);
 
-		ActionType::getTypes(list);
-		list.push_front(trUtf8("Default"));
+		list = ActionType::getTypes();
+		list.push_front(tr("Default"));
 		del_action_cmb->addItems(list);
 		upd_action_cmb->addItems(list);
 
@@ -157,13 +138,13 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 					 rel_attribs_tbw->widget(AttributesTab), rel_attribs_tbw->widget(ConstraintsTab),
 					 rel_attribs_tbw->widget(SpecialPkTab), rel_attribs_tbw->widget(AdvancedTab) };
 
-		tab_labels=QStringList{ QString(), rel_attribs_tbw->tabText(SettingsTab),
+		tab_labels=QStringList{ "", rel_attribs_tbw->tabText(SettingsTab),
 							 rel_attribs_tbw->tabText(AttributesTab), rel_attribs_tbw->tabText(ConstraintsTab),
 							 rel_attribs_tbw->tabText(SpecialPkTab), rel_attribs_tbw->tabText(AdvancedTab)};
 
 		part_bound_expr_txt=new NumberedTextEditor(this, true);
 		part_bound_expr_hl=new SyntaxHighlighter(part_bound_expr_txt);
-		part_bound_expr_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
+		part_bound_expr_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 		dynamic_cast<QGridLayout *>(part_bound_expr_gb->layout())->addWidget(part_bound_expr_txt, 1, 0);
 
 		connect(deferrable_chk, SIGNAL(toggled(bool)), deferral_cmb, SLOT(setEnabled(bool)));
@@ -176,28 +157,28 @@ RelationshipWidget::RelationshipWidget(QWidget *parent): BaseObjectWidget(parent
 																	dynamic_cast<BaseRelationship *>(this->object)->getRelationshipType() != BaseRelationship::Relationship1n);
 		});
 
-		connect(attributes_tab, SIGNAL(s_rowsRemoved(void)), this, SLOT(removeObjects(void)));
-		connect(attributes_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addObject(void)));
+		connect(attributes_tab, SIGNAL(s_rowsRemoved()), this, SLOT(removeObjects()));
+		connect(attributes_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addObject()));
 		connect(attributes_tab, SIGNAL(s_rowEdited(int)), this, SLOT(editObject(int)));
 		connect(attributes_tab, SIGNAL(s_rowRemoved(int)), this, SLOT(removeObject(int)));
 		connect(attributes_tab, SIGNAL(s_rowDuplicated(int,int)), this, SLOT(duplicateObject(int,int)));
 
-		connect(constraints_tab, SIGNAL(s_rowsRemoved(void)), this, SLOT(removeObjects(void)));
-		connect(constraints_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addObject(void)));
+		connect(constraints_tab, SIGNAL(s_rowsRemoved()), this, SLOT(removeObjects()));
+		connect(constraints_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addObject()));
 		connect(constraints_tab, SIGNAL(s_rowEdited(int)), this, SLOT(editObject(int)));
 		connect(constraints_tab, SIGNAL(s_rowRemoved(int)), this, SLOT(removeObject(int)));
 		connect(constraints_tab, SIGNAL(s_rowDuplicated(int,int)), this, SLOT(duplicateObject(int,int)));
 
-		connect(defaults_rb, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
-		connect(including_rb, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
-		connect(excluding_rb, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
+		connect(defaults_rb, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
+		connect(including_rb, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
+		connect(excluding_rb, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
 
-		connect(defaults_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
-		connect(constraints_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
-		connect(comments_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
-		connect(indexes_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
-		connect(storage_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
-		connect(all_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions(void)));
+		connect(defaults_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
+		connect(constraints_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
+		connect(comments_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
+		connect(indexes_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
+		connect(storage_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
+		connect(all_chk, SIGNAL(toggled(bool)), this, SLOT(selectCopyOptions()));
 
 		connect(custom_color_chk, SIGNAL(toggled(bool)), color_picker, SLOT(setEnabled(bool)));
 
@@ -241,8 +222,7 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 {
 	unsigned rel_type, i;
 	Relationship *aux_rel=nullptr;
-	bool rel1n=false, relnn=false, relgen_dep=false,
-			use_name_patterns=false, has_foreign_tab=false;
+	bool rel1n=false, relnn=false, relgen_dep=false, has_foreign_tab=false;
 
 	if(!base_rel)
 		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
@@ -267,18 +247,18 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 	{
 		if(base_rel->getRelationshipType()!=BaseRelationship::RelationshipFk)
 		{
-			ref_table_lbl->setText(trUtf8("Referer View:"));
-			ref_table_ht->setText(trUtf8("Referer view references one or more columns of a table to construct it's own columns."));
-			recv_table_ht->setText(trUtf8("Referenced table has its columns referenced by a view in order to construct the columns of this latter."));
+			ref_table_lbl->setText(tr("Referer View:"));
+			ref_table_txt->setToolTip(tr("<p>Referer view references one or more columns of a table to construct it's own columns.</p>"));
+			recv_table_txt->setToolTip(tr("<p>Referenced table has its columns referenced by a view in order to construct the columns of this latter.</p>"));
 		}
 		else
 		{
-			ref_table_lbl->setText(trUtf8("Referer Table:"));
-			ref_table_ht->setText(trUtf8("Referer table references one or more columns of a table through foreign keys. This is the (n) side of relationship."));
-			recv_table_ht->setText(trUtf8("Referenced table has its columns referenced by a table's foreign key. This is the (1) side of relationship."));
+			ref_table_lbl->setText(tr("Referer Table:"));
+			ref_table_txt->setToolTip(tr("<p>Referer table references one or more columns of a table through foreign keys. This is the (n) side of relationship.</p>"));
+			recv_table_txt->setToolTip(tr("<p>Referenced table has its columns referenced by a table's foreign key. This is the (1) side of relationship.</p>"));
 		}
 
-		recv_table_lbl->setText(trUtf8("Referenced Table:"));
+		recv_table_lbl->setText(tr("Referenced Table:"));
 
 		ref_table_txt->setPlainText(base_rel->getTable(BaseRelationship::SrcTable)->getName(true));
 		recv_table_txt->setPlainText(base_rel->getTable(BaseRelationship::DstTable)->getName(true));
@@ -287,32 +267,32 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 	{
 		if(rel_type == BaseRelationship::RelationshipPart)
 		{
-		  ref_table_lbl->setText(trUtf8("Partitioned Table:"));
-		  ref_table_ht->setText(trUtf8("Partitioned table is the one which is splitted into smaller pieces (partitions). This table is where the partitioning strategy or type is defined."));
+			ref_table_lbl->setText(tr("Partitioned Table:"));
+			ref_table_txt->setToolTip(tr("<p>Partitioned table is the one which is splitted into smaller pieces (partitions). This table is where the partitioning strategy or type is defined.</p>"));
 
-		  recv_table_lbl->setText(trUtf8("Partition Table:"));
-		  recv_table_ht->setText(trUtf8("Partition table is the one attached to a partitioned table in which operations over data will be routed (according to the paritionig rule) when trying to handle the partitioned table."));
+			recv_table_lbl->setText(tr("Partition Table:"));
+			recv_table_txt->setToolTip(tr("<p>Partition table is the one attached to a partitioned table in which operations over data will be routed (according to the paritionig rule) when trying to handle the partitioned table.</p>"));
 
-		  ref_table_txt->setPlainText(aux_rel->getReferenceTable()->getName(true));
-		  recv_table_txt->setPlainText(aux_rel->getReceiverTable()->getName(true));
+			ref_table_txt->setPlainText(aux_rel->getReferenceTable()->getName(true));
+			recv_table_txt->setPlainText(aux_rel->getReceiverTable()->getName(true));
 		}
 		else if(rel_type!=BaseRelationship::RelationshipNn)
 		{
-			ref_table_lbl->setText(trUtf8("Reference Table:"));
-			ref_table_ht->setText(trUtf8("Reference table has the columns from its primary key will copied to the receiver table in order to represent the linking between them. This is the (1) side of relationship."));
+			ref_table_lbl->setText(tr("Reference Table:"));
+			ref_table_txt->setToolTip(tr("<p>Reference table has the columns from its primary key will copied to the receiver table in order to represent the linking between them. This is the (1) side of relationship.</p>"));
 
-			recv_table_lbl->setText(trUtf8("Receiver Table:"));
-			recv_table_ht->setText(trUtf8("Receiver (or referer) table will receive the generated columns and the foreign key in order to represent the linking between them. This is the (n) side of relationship."));
+			recv_table_lbl->setText(tr("Receiver Table:"));
+			recv_table_txt->setToolTip(tr("<p>Receiver (or referer) table will receive the generated columns and the foreign key in order to represent the linking between them. This is the (n) side of relationship.</p>"));
 
 			ref_table_txt->setPlainText(aux_rel->getReferenceTable()->getName(true));
 			recv_table_txt->setPlainText(aux_rel->getReceiverTable()->getName(true));
 		}
 		else
 		{
-			ref_table_lbl->setText(trUtf8("Reference Table:"));
-			ref_table_ht->setText(trUtf8("In many-to-many relationships both tables are used as reference to generate the table that represents the linking. Columns from both tables are copied to the resultant table and two foreign keys are created as well in order to reference each participant table."));
-			recv_table_lbl->setText(trUtf8("Reference Table:"));
-			recv_table_ht->setText(ref_table_ht->getText());
+			ref_table_lbl->setText(tr("Reference Table:"));
+			ref_table_txt->setToolTip(tr("<p>In many-to-many relationships both tables are used as reference to generate the table that represents the linking. Columns from both tables are copied to the resultant table and two foreign keys are created as well in order to reference each participant table.</p>"));
+			recv_table_lbl->setText(tr("Reference Table:"));
+			recv_table_txt->setToolTip(ref_table_txt->toolTip());
 			ref_table_txt->setPlainText(base_rel->getTable(BaseRelationship::SrcTable)->getName(true));
 			recv_table_txt->setPlainText(base_rel->getTable(BaseRelationship::DstTable)->getName(true));
 		}
@@ -328,8 +308,8 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 	}
 
 	disable_sql_chk->setVisible(base_rel->getObjectType()==ObjectType::Relationship);
-	table1_mand_chk->setText(base_rel->getTable(BaseRelationship::SrcTable)->getName() + trUtf8(" is required"));
-	table2_mand_chk->setText(base_rel->getTable(BaseRelationship::DstTable)->getName() + trUtf8(" is required"));
+	table1_mand_chk->setText(base_rel->getTable(BaseRelationship::SrcTable)->getName() + tr(" is required"));
+	table2_mand_chk->setText(base_rel->getTable(BaseRelationship::DstTable)->getName() + tr(" is required"));
 
 	if(aux_rel)
 	{
@@ -386,9 +366,7 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 							rel_type==BaseRelationship::RelationshipPart ||
 							rel_type==BaseRelationship::RelationshipFk);
 
-	use_name_patterns=(rel1n || relnn ||
-					   (relgen_dep && base_rel->getObjectType()==ObjectType::Relationship));
-
+	use_name_patterns = (rel1n || relnn || (relgen_dep && base_rel->getObjectType()==ObjectType::Relationship));
 	name_patterns_grp->setVisible(use_name_patterns);
 
 	dst_col_pattern_txt->setEnabled(relnn);
@@ -417,7 +395,6 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 
 	relnn_tab_name_lbl->setVisible(relnn);
 	relnn_tab_name_edt->setVisible(relnn);
-	gen_tab_name_hint->setVisible(relnn);
 
 	part_bound_expr_gb->setVisible(rel_type==BaseRelationship::RelationshipPart);
 
@@ -430,11 +407,14 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 			rel_attribs_tbw->addTab(tabs[i], tab_labels[i]);
 	}
 	else if(relgen_dep && base_rel->getObjectType()==ObjectType::Relationship && !has_foreign_tab)
+	{
+		rel_attribs_tbw->addTab(tabs[SettingsTab], tab_labels[SettingsTab]);
 		rel_attribs_tbw->addTab(tabs[SpecialPkTab], tab_labels[SpecialPkTab]);
+	}
 
 	if(base_rel->getObjectType()==ObjectType::Relationship ||
-			(base_rel->getObjectType()==ObjectType::BaseRelationship &&
-			 base_rel->getRelationshipType()==BaseRelationship::RelationshipFk))
+		 (base_rel->getObjectType()==ObjectType::BaseRelationship &&
+			base_rel->getRelationshipType()==BaseRelationship::RelationshipFk))
 		rel_attribs_tbw->addTab(tabs[AdvancedTab], tab_labels[AdvancedTab]);
 
 	copy_options_grp->setVisible(base_rel->getObjectType()==ObjectType::Relationship &&
@@ -461,7 +441,7 @@ void RelationshipWidget::setAttributes(DatabaseModel *model, OperationList *op_l
 	}
 }
 
-QSize RelationshipWidget::getIdealSize(void)
+QSize RelationshipWidget::getIdealSize()
 {
 	unsigned rel_type = 0;
 
@@ -470,11 +450,11 @@ QSize RelationshipWidget::getIdealSize(void)
 
 	if(rel_type == BaseRelationship::RelationshipFk ||
 	   (BaseRelationship::RelationshipDep && this->object && this->object->getObjectType()==ObjectType::BaseRelationship))
-		return(QSize(640, 320));
+		return QSize(640, 320);
 	else if(BaseRelationship::RelationshipGen)
-		return(QSize(640, 520));
+		return QSize(640, 520);
 	else
-		return(QSize(640, 680));
+		return QSize(640, 680);
 }
 
 void RelationshipWidget::useFKGlobalSettings(bool value)
@@ -545,7 +525,7 @@ void RelationshipWidget::usePatternGlobalSettings(bool value)
 	}
 }
 
-void RelationshipWidget::generateBoundingExpr(void)
+void RelationshipWidget::generateBoundingExpr()
 {
 	PartitioningType part_type = part_type_lbl->text();
 	QString tmpl;
@@ -557,7 +537,7 @@ void RelationshipWidget::generateBoundingExpr(void)
 	else
 		tmpl = QString("WITH (MODULUS m, REMAINDER r)");
 
-	part_bound_expr_txt->setPlainText(QString());
+	part_bound_expr_txt->setPlainText("");
 	part_bound_expr_txt->setPlainText(tmpl);
 	default_part_chk->setChecked(false);
 }
@@ -598,7 +578,7 @@ void RelationshipWidget::listObjects(ObjectType obj_type)
 	}
 }
 
-void RelationshipWidget::listAdvancedObjects(void)
+void RelationshipWidget::listAdvancedObjects()
 {
 	BaseRelationship *base_rel=nullptr;
 	Relationship *rel=nullptr;
@@ -751,10 +731,10 @@ int RelationshipWidget::openEditingForm(TableObject *object, BaseObject *parent)
 	res = editing_form.exec();
 	GeneralConfigWidget::saveWidgetGeometry(&editing_form, object_wgt->metaObject()->className());
 
-	return(res);
+	return res;
 }
 
-void RelationshipWidget::addObject(void)
+void RelationshipWidget::addObject()
 {
 	ObjectType obj_type=ObjectType::BaseObject;
 
@@ -891,7 +871,7 @@ void RelationshipWidget::showObjectData(TableObject *object, int row)
 	tab->setRowData(QVariant::fromValue<void *>(object), row);
 }
 
-void RelationshipWidget::removeObjects(void)
+void RelationshipWidget::removeObjects()
 {
 	Relationship *rel=nullptr;
 	ObjectType obj_type=ObjectType::BaseObject;
@@ -985,7 +965,7 @@ void RelationshipWidget::removeObject(int row)
 	}
 }
 
-void RelationshipWidget::selectCopyOptions(void)
+void RelationshipWidget::selectCopyOptions()
 {
 	all_chk->setEnabled(!defaults_rb->isChecked());
 
@@ -1012,7 +992,7 @@ void RelationshipWidget::selectCopyOptions(void)
 	}
 }
 
-void RelationshipWidget::listSpecialPkColumns(void)
+void RelationshipWidget::listSpecialPkColumns()
 {
 	Relationship *aux_rel=dynamic_cast<Relationship *>(this->object);
 
@@ -1052,7 +1032,7 @@ void RelationshipWidget::listSpecialPkColumns(void)
 	}
 }
 
-void RelationshipWidget::applyConfiguration(void)
+void RelationshipWidget::applyConfiguration()
 {
 	try
 	{
@@ -1084,26 +1064,28 @@ void RelationshipWidget::applyConfiguration(void)
 
 		if(this->object->getObjectType()==ObjectType::Relationship)
 		{
-			QPlainTextEdit *pattern_fields[]={ src_col_pattern_txt, dst_col_pattern_txt,
-																				 src_fk_pattern_txt, dst_fk_pattern_txt,
-																				 pk_pattern_txt, uq_pattern_txt, pk_col_pattern_txt };
-			unsigned pattern_ids[]= { Relationship::SrcColPattern, Relationship::DstColPattern,
-																Relationship::SrcFkPattern, Relationship::DstFkPattern,
-																Relationship::PkPattern, Relationship::UqPattern, Relationship::PkColPattern };
+			vector<QPlainTextEdit *> pattern_fields={ src_col_pattern_txt, dst_col_pattern_txt,
+																								pk_pattern_txt, uq_pattern_txt,
+																								src_fk_pattern_txt, dst_fk_pattern_txt,
+																								pk_col_pattern_txt };
 
-			rel=dynamic_cast<Relationship *>(base_rel);
+			vector<unsigned> pattern_ids= { Relationship::SrcColPattern, Relationship::DstColPattern,
+																			Relationship::PkPattern, Relationship::UqPattern,
+																			Relationship::SrcFkPattern, Relationship::DstFkPattern,
+																			Relationship::PkColPattern };
 
-			if(name_patterns_grp->isVisible())
+			rel = dynamic_cast<Relationship *>(base_rel);
+
+			if(use_name_patterns)
 			{
-				count=sizeof(pattern_ids)/sizeof(unsigned);
-				for(i=0; i < count; i++)
-					rel->setNamePattern(pattern_ids[i], pattern_fields[i]->toPlainText());
+				for(auto &patt_id : pattern_ids)
+					rel->setNamePattern(patt_id, pattern_fields[patt_id]->toPlainText());
 			}
 
 			rel_type=rel->getRelationshipType();
 			rel->blockSignals(true);
 
-			rel->setPartitionBoundingExpr(default_part_chk->isChecked() ? QString() : part_bound_expr_txt->toPlainText());
+			rel->setPartitionBoundingExpr(default_part_chk->isChecked() ? "" : part_bound_expr_txt->toPlainText());
 
 			if(!defaults_rb->isChecked())
 			{
@@ -1139,8 +1121,8 @@ void RelationshipWidget::applyConfiguration(void)
 				rel->setTableNameRelNN(relnn_tab_name_edt->text());
 
 			if(rel_type==BaseRelationship::Relationship1n ||
-					rel_type==BaseRelationship::Relationship11 ||
-					rel_type==BaseRelationship::RelationshipNn)
+				 rel_type==BaseRelationship::Relationship11 ||
+				 rel_type==BaseRelationship::RelationshipNn)
 			{
 				rel->setDeferrable(deferrable_chk->isChecked());
 				rel->setDeferralType(DeferralType(deferral_cmb->currentText()));
@@ -1191,11 +1173,12 @@ void RelationshipWidget::applyConfiguration(void)
 	catch(Exception &e)
 	{
 		model->validateRelationships();
+		QApplication::restoreOverrideCursor();
 		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
-void RelationshipWidget::cancelConfiguration(void)
+void RelationshipWidget::cancelConfiguration()
 {
 	BaseObjectWidget::cancelChainedOperation();
 }
