@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ class ResultSetModel: public QAbstractTableModel {
 		virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
 		virtual Qt::ItemFlags flags(const QModelIndex &) const;
 		void append(ResultSet &res);
-		bool isEmpty(void);
+		bool isEmpty();
 };
 
 #endif
