@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 #include "syntaxhighlighter.h"
 #include "numberedtexteditor.h"
+#include "qtcompat/qplaintexteditcompat.h"
 
 QFont SyntaxHighlighter::default_font=QFont(QString("Source Code Pro"), 10);
 
@@ -32,7 +33,7 @@ SyntaxHighlighter::SyntaxHighlighter(QPlainTextEdit *parent, bool single_line_mo
 	parent->installEventFilter(this);
 
 	if(use_custom_tab_width)
-		parent->setTabStopWidth(NumberedTextEditor::getTabWidth());
+		QtCompat::setTabStopDistance(parent, NumberedTextEditor::getTabDistance());
 
 	//Adjusting the size of the parent input according to the current font size
 	if(single_line_mode)
@@ -55,7 +56,7 @@ bool SyntaxHighlighter::eventFilter(QObject *object, QEvent *event)
 			 dynamic_cast<QKeyEvent *>(event)->key()==Qt::Key_Enter))
 	{
 		event->ignore();
-		return(true);
+		return true;
 	}
 
 	/* If the user is about press Control to paste contents or Right mouse button in
@@ -72,15 +73,15 @@ bool SyntaxHighlighter::eventFilter(QObject *object, QEvent *event)
 			qApp->clipboard()->setText(qApp->clipboard()->mimeData()->text());
 	}
 
-	return(QSyntaxHighlighter::eventFilter(object, event));
+	return QSyntaxHighlighter::eventFilter(object, event);
 }
 
 bool SyntaxHighlighter::hasInitialAndFinalExprs(const QString &group)
 {
-	return(initial_exprs.count(group) && final_exprs.count(group));
+	return (initial_exprs.count(group) && final_exprs.count(group));
 }
 
-void SyntaxHighlighter::configureAttributes(void)
+void SyntaxHighlighter::configureAttributes()
 {
 	conf_loaded=false;
 }
@@ -103,10 +104,14 @@ void SyntaxHighlighter::highlightBlock(const QString &txt)
 		setCurrentBlockState(SimpleBlock);
 	}
 
-	/* If the previous block info is a open multiline expression the current block will inherit this settings
-	 to force the same text formatting */
+	/* If the previous block info is an open multiline expression the current block will inherit this settings
+	 * to force the same text formatting.
+	 *
+	 * There is a special case for empty texts that are inserted right after a
+	 * multiline expression, here we force the inheritance of the formatting from the previous block anyway.
+	 * This is done in order to avoid the next line (after the blank one) to lost track of the previous formatting */
 	if(prev_info && currentBlock().previous().userState()==OpenExprBlock &&
-		 currentBlockState() == OpenExprBlock)
+		 (currentBlockState() == OpenExprBlock || (txt.isEmpty() && currentBlockState() < 0)))
 	{
 		info->group=prev_info->group;
 		info->has_exprs=prev_info->has_exprs;
@@ -116,11 +121,13 @@ void SyntaxHighlighter::highlightBlock(const QString &txt)
 
 	if(!txt.isEmpty())
 	{
-		QString text=txt + QChar('\n'), word, group;
+		QString text, word, group;
 		unsigned i=0, len, idx=0, i1;
 		int match_idx, match_len, aux_len, start_col;
 		QChar chr_delim, lookahead_chr;
-		len=text.length();
+
+		text = txt + QString("\n");
+		len = text.length();
 
 		do
 		{
@@ -136,20 +143,26 @@ void SyntaxHighlighter::highlightBlock(const QString &txt)
 				if(word_separators.contains(text[i]))
 				{
 					while(i < len && word_separators.contains(text[i]))
-						word+=text[i++];
+					{
+						word += text[i];
+						i++;
+					}
 				}
 				//If the char is a word delimiter
 				else if(word_delimiters.contains(text[i]))
 				{
-					chr_delim=text[i++];
-					word+=chr_delim;
+					chr_delim = text[i++];
+					word += chr_delim;
 
-					while(i < len && chr_delim!=text[i])
-						word+=text[i++];
-
-					if(i < len && text[i]==chr_delim)
+					while(i < len && chr_delim != text[i])
 					{
-						word+=chr_delim;
+						word += text[i];
+						i++;
+					}
+
+					if(i < len && text[i] == chr_delim)
+					{
+						word += chr_delim;
 						i++;
 					}
 				}
@@ -162,7 +175,8 @@ void SyntaxHighlighter::highlightBlock(const QString &txt)
 							!ignored_chars.contains(text[i]) &&
 							!word_delimiters.contains(text[i]))
 					{
-						word+=text[i++];
+						word += text[i];
+						i++;
 					}
 
 					/* This is an workaround for multi lined groups which use word delimiters
@@ -183,13 +197,14 @@ void SyntaxHighlighter::highlightBlock(const QString &txt)
 					this because the final expression of the group contains the word delimiter '. In order to force the highlight stop
 					in the last ' we include it in the current evaluated word and increment the position in the text so the next
 					word starts without the word delimiter. */
-					if(word_delimiters.contains(text[i]) && prev_info && !prev_info->group.isEmpty() && prev_info->has_exprs)
+					if(i < len && word_delimiters.contains(text[i]) && prev_info && !prev_info->group.isEmpty() && prev_info->has_exprs)
 					{
 						for(auto exp : final_exprs[prev_info->group])
 						{
 							if(exp.pattern().contains(text[i]))
 							{
-								word+=text[i++];
+								word += text[i];
+								i++;
 								break;
 							}
 						}
@@ -264,7 +279,7 @@ QString SyntaxHighlighter::identifyWordGroup(const QString &word, const QChar &l
 		info->has_exprs=hasInitialAndFinalExprs(group);
 		info->group=group;
 
-		return(group);
+		return group;
 	}
 	else
 	{
@@ -279,7 +294,7 @@ QString SyntaxHighlighter::identifyWordGroup(const QString &word, const QChar &l
 		}
 
 		if(!match)
-			return(QString());
+			return "";
 		else
 		{
 			info->group=group;
@@ -288,7 +303,7 @@ QString SyntaxHighlighter::identifyWordGroup(const QString &word, const QChar &l
 				info->has_exprs=hasInitialAndFinalExprs(group);
 
 			info->is_expr_closed=false;
-			return(group);
+			return group;
 		}
 	}
 }
@@ -331,15 +346,15 @@ bool SyntaxHighlighter::isWordMatchGroup(const QString &word, const QString &gro
 		if(match) break;
 	}
 
-	return(match);
+	return match;
 }
 
-bool SyntaxHighlighter::isConfigurationLoaded(void)
+bool SyntaxHighlighter::isConfigurationLoaded()
 {
-	return(conf_loaded);
+	return conf_loaded;
 }
 
-void SyntaxHighlighter::clearConfiguration(void)
+void SyntaxHighlighter::clearConfiguration()
 {
 	initial_exprs.clear();
 	final_exprs.clear();
@@ -372,13 +387,10 @@ void SyntaxHighlighter::loadConfiguration(const QString &filename)
 		{
 			clearConfiguration();
 			xmlparser.restartParser();
-			xmlparser.setDTDFile(GlobalAttributes::TmplConfigurationDir +
-								 GlobalAttributes::DirSeparator +
-								 GlobalAttributes::ObjectDTDDir +
-								 GlobalAttributes::DirSeparator +
-								 GlobalAttributes::CodeHighlightConf +
-								 GlobalAttributes::ObjectDTDExt,
-								 GlobalAttributes::CodeHighlightConf);
+			xmlparser.setDTDFile(GlobalAttributes::getTmplConfigurationFilePath(GlobalAttributes::ObjectDTDDir,
+																																					GlobalAttributes::CodeHighlightConf +
+																																					GlobalAttributes::ObjectDTDExt),
+													 GlobalAttributes::CodeHighlightConf);
 
 			xmlparser.loadXMLFile(filename);
 
@@ -587,14 +599,14 @@ vector<QRegExp> SyntaxHighlighter::getExpressions(const QString &group_name, boo
 	map<QString, vector<QRegExp> > *expr_map=(!final_expr ? &initial_exprs : &final_exprs);
 
 	if(expr_map->count(group_name) > 0)
-		return(expr_map->at(group_name));
+		return expr_map->at(group_name);
 	else
-		return(vector<QRegExp>());
+		return vector<QRegExp>();
 }
 
-QChar SyntaxHighlighter::getCompletionTrigger(void)
+QChar SyntaxHighlighter::getCompletionTrigger()
 {
-	return(completion_trigger);
+	return completion_trigger;
 }
 
 void SyntaxHighlighter::setFormat(int start, int count, const QString &group)
