@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2020 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,8 +33,7 @@ class TagWidget: public BaseObjectWidget, public Ui::TagWidget {
 	private:
 		Q_OBJECT
 
-		/*! \brief Stores all color picker using the attribute the represents as map key.
-				These attributes are: TABLE_NAME, TABLE_SCHEMA_NAME, TABLE_TITLE, TABLE_BODY, TABLE_EXT_BODY */
+		//! \brief Stores all color picker using the attribute the represents as map key.
 		map<QString, ColorPickerWidget *> color_pickers;
 
 	public:
@@ -43,7 +42,7 @@ class TagWidget: public BaseObjectWidget, public Ui::TagWidget {
 		void setAttributes(DatabaseModel *model, OperationList *op_list, Tag *tag);
 
 	public slots:
-		void applyConfiguration(void);
+		void applyConfiguration();
 };
 
 #endif
